@@ -5,29 +5,23 @@
 #ifndef ABOUTDIALOG_H
 #define ABOUTDIALOG_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
-#ifndef gbool
-# define gbool	gboolean
-#endif
 
 /*
- *	About dialog structure:
+ *	About Dialog:
  */
 typedef struct {
 
-	gboolean initialized;
-	gboolean map_state;
-
-	gpointer core_ptr;
-
-	GtkWidget *toplevel;
-	GtkWidget *main_label;
-	GtkWidget *plugins_list;
-	GtkWidget *ok_btn;
-
+	gboolean	initialized,
+			map_state;
+	gpointer	core_ptr;
+	GtkWidget	*toplevel,
+			*main_label,
+			*plugins_list,
+			*ok_btn;
 } about_dialog_struct;
+#define ABOUT_DIALOG(p)	((about_dialog_struct *)(p))
 
 
 extern about_dialog_struct *AboutDialogNew(void *core_ptr);
