@@ -1,7 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -71,15 +70,13 @@
 /*
  *	Confirmation Dialog:
  */
-typedef struct _cdialog_struct			cdialog_struct;
-struct _cdialog_struct {
-
-	gboolean	initialized;
+typedef struct _CDlg			CDlg;
+struct _CDlg {
 
+	GtkWidget	*toplevel;
 	GtkAccelGroup	*accelgrp;
 
-	GtkWidget	*toplevel,
-			*main_vbox,
+	GtkWidget	*main_vbox,
 			*label_hbox,
 			*icon_pm,
 			*label,
@@ -101,19 +98,21 @@ struct _cdialog_struct {
 	GtkWidget	*last_transient_for;	/* Do not reference */
 	cdialog_icon	last_icon_code;
 
+	gint		response_code;
+	gint		block_loop_level;
+
 };
-#define CDIALOG(p)	((cdialog_struct *)(p))
+#define CDLG(p)		((CDlg *)(p))
 
 
 /* Callbacks */
-static void CDialogDestroyCB(GtkObject *object, gpointer data);       
 static gint CDialogCloseCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
 static void CDialogButtonCB(GtkWidget *widget, gpointer data);
 
 static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code);
-static void CDialogLoadIcon(cdialog_struct *d, guint8 **icon_data);
+static void CDialogLoadIcon(CDlg *d, guint8 **icon_data);
 
 /* Front Ends */
 gint CDialogInit(void);
@@ -123,7 +122,7 @@ gboolean CDialogIsQuery(void);
 void CDialogBreakQuery(void);
 GtkWidget *CDialogGetToplevel(void);
 static void CDialogRemapButtons(
-	cdialog_struct *d,
+	CDlg *d,
 	cdialog_btn_flags show_buttons,		/* Any of CDIALOG_BTNFLAG_* */
 	cdialog_btn_flags default_button	/* One of CDIALOG_BTNFLAG_* */
 );
@@ -206,31 +205,24 @@ void CDialogShutdown(void);
 #endif
 
 
-static gint response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-static gint block_loop_level;
-static cdialog_struct cdialog;
+static CDlg		*cdlg;
 
 
-/*
- *	GtkWindow "destroy" signal callback.
- */
-static void CDialogDestroyCB(GtkObject *object, gpointer data)
-{
-	return;
-}
-
 /*
  *	GtkWindow "delete_event" signal callback.
  */
 static gint CDialogCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-	cdialog_struct *d = CDIALOG(data);
+	CDlg *d = CDLG(data);
 	if((widget == NULL) || (d == NULL))
 	    return(FALSE);
 
-	response_code = CDIALOG_RESPONSE_CANCEL;
+	d->response_code = CDIALOG_RESPONSE_CANCEL;
+
+	/* Break out of one main loop level */
 	gtk_main_quit();
-	block_loop_level--;
+	d->block_loop_level--;
+
 	return(TRUE);
 }
 
@@ -240,7 +232,7 @@ static gint CDialogCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 static void CDialogButtonCB(GtkWidget *widget, gpointer data)
 {
 	GtkWidget *w;
-	cdialog_struct *d = CDIALOG(data);
+	CDlg *d = CDLG(data);
 	if((widget == NULL) || (d == NULL))
 	    return;
 
@@ -253,18 +245,18 @@ static void CDialogButtonCB(GtkWidget *widget, gpointer data)
 
 	/* Check which button was pressed */
 	if(widget == d->ok_btn)
-	    response_code = CDIALOG_RESPONSE_OK;
+	    d->response_code = CDIALOG_RESPONSE_OK;
 	else if(widget == d->yes_btn)
-	    response_code = CDIALOG_RESPONSE_YES;
+	    d->response_code = CDIALOG_RESPONSE_YES;
 	else if(widget == d->yes_to_all_btn)
-	    response_code = CDIALOG_RESPONSE_YES_TO_ALL;
+	    d->response_code = CDIALOG_RESPONSE_YES_TO_ALL;
 	else if(widget == d->no_btn)
-	    response_code = CDIALOG_RESPONSE_NO;
+	    d->response_code = CDIALOG_RESPONSE_NO;
 	else if(widget == d->cancel_btn)
-	    response_code = CDIALOG_RESPONSE_CANCEL;
+	    d->response_code = CDIALOG_RESPONSE_CANCEL;
 	else if(widget == d->help_btn)
 	{
-	    response_code = CDIALOG_RESPONSE_HELP;
+	    d->response_code = CDIALOG_RESPONSE_HELP;
 	    w = d->help_vbox;
 	    if(w != NULL)
 		gtk_widget_show(w);
@@ -275,9 +267,9 @@ static void CDialogButtonCB(GtkWidget *widget, gpointer data)
 	    return;	/* Return, do not break out of block loop */
 	}
 
-	/* Need to break out of the blocked loop */
+	/* Break out of one main loop level */
 	gtk_main_quit();
-	block_loop_level--;
+	d->block_loop_level--;
 }
 
 
@@ -421,7 +413,7 @@ static guint8 **CDialogGetMessageIconDataFromCode(cdialog_icon icon_code)
 /*
  *	Updates the CDialog's icons.
  */
-static void CDialogLoadIcon(cdialog_struct *d, guint8 **icon_data)
+static void CDialogLoadIcon(CDlg *d, guint8 **icon_data)
 {
 	gint width, height;
 	GdkBitmap *mask;
@@ -441,8 +433,8 @@ static void CDialogLoadIcon(cdialog_struct *d, guint8 **icon_data)
 	gtk_pixmap_set(GTK_PIXMAP(w), pixmap, mask);
 	gtk_widget_set_usize(w, width, height);
 
-	GDK_PIXMAP_UNREF(pixmap)
-	GDK_BITMAP_UNREF(mask)
+	GDK_PIXMAP_UNREF(pixmap);
+	GDK_BITMAP_UNREF(mask);
 
 	/* Toplevel needs to be resized since new icon size may be
 	 * different from the previous one
@@ -469,22 +461,22 @@ gint CDialogInit(void)
 	GtkRcStyle *rcstyle;
 	GtkStyle *style;
 	GtkWidget *w, *parent, *parent2, *parent3, *parent4, *parent5;
-	cdialog_struct *d = &cdialog;
+	CDlg *d;
 
 	/* Already initialized? */
-	if(d->initialized)
-	    return(-2);
+	if(cdlg != NULL)
+	    return(0);
+
+	/* Create new Dialog */
+	cdlg = d = CDLG(g_malloc0(sizeof(CDlg)));
+	if(d == NULL)
+	    return(-3);
 
 	/* Reset globals */
-	response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	block_loop_level = 0;
-
-	/* Reset values */
-	memset(d, 0x00, sizeof(cdialog_struct));
-
-	d->initialized = TRUE;
 	d->last_transient_for = NULL;
 	d->last_icon_code = CDIALOG_ICON_INFO;
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	d->block_loop_level = 0;
 
 	/* Keyboard accelerator group */
 	d->accelgrp = accelgrp = gtk_accel_group_new();
@@ -536,11 +528,6 @@ gint CDialogInit(void)
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(CDialogCloseCB), d
 	);
-	gtk_signal_connect(
-	    GTK_OBJECT(w), "destroy",
-	    GTK_SIGNAL_FUNC(CDialogDestroyCB), d
-	);
-	gtk_container_border_width(GTK_CONTAINER(w), 0);
 	gtk_window_add_accel_group(GTK_WINDOW(w), accelgrp);
 	style = gtk_widget_get_style(w);
 	parent = w;
@@ -576,8 +563,8 @@ gint CDialogInit(void)
 	    gtk_widget_set_usize(w, width, height);
 	    gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, FALSE, 0);
 	    gtk_widget_show(w);
-	    GDK_PIXMAP_UNREF(pixmap)
-	    GDK_BITMAP_UNREF(mask)
+	    GDK_PIXMAP_UNREF(pixmap);
+	    GDK_BITMAP_UNREF(mask);
 	}
 
 	/* Hbox for message label */
@@ -679,8 +666,8 @@ gint CDialogInit(void)
 	    gtk_box_pack_start(GTK_BOX(parent5), w, TRUE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);         
 	    gtk_widget_show(w);
-	    GDK_PIXMAP_UNREF(pixmap)
-	    GDK_BITMAP_UNREF(mask)
+	    GDK_PIXMAP_UNREF(pixmap);
+	    GDK_BITMAP_UNREF(mask);
 	}
 
 	/* Hbox for help label */
@@ -726,25 +713,13 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, GDK_space, 0, GTK_ACCEL_VISIBLE,
-	    GTK_OBJECT(w), "clicked"
-	);
-	gtk_accel_group_add(
-	    accelgrp, GDK_Return, 0, GTK_ACCEL_VISIBLE,
-	    GTK_OBJECT(w), "clicked"
-	);
-	gtk_accel_group_add(
-	    accelgrp, GDK_3270_Enter, 0, GTK_ACCEL_VISIBLE,
-	    GTK_OBJECT(w), "clicked"
-	);
-	gtk_accel_group_add(
-	    accelgrp, GDK_KP_Enter, 0, GTK_ACCEL_VISIBLE,
-	    GTK_OBJECT(w), "clicked"
-	);
-	gtk_accel_group_add(
-	    accelgrp, GDK_ISO_Enter, 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_o, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	/* Let the default/focus grabbed button receive the
+	 * GDK_space and GDK_Return keys
+	 */
+	GUIButtonLabelUnderline(w, GDK_o);
 
 	/* Yes button */
 	d->yes_btn = w = GUIButtonPixmapLabelH(
@@ -779,9 +754,11 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'y', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_y, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_y);
+
 
 	/* Yes to all button */
 	d->yes_to_all_btn = w = GUIButtonPixmapLabelH(
@@ -816,9 +793,10 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'a', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_a, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_a);
 
 	/* No button */  
 	d->no_btn = w = GUIButtonPixmapLabelH(
@@ -853,9 +831,11 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'n', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_n, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_n);
+
 
 	/* Cancel button */
 	d->cancel_btn = w = GUIButtonPixmapLabelH(
@@ -890,13 +870,14 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'c', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_c, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
 	gtk_accel_group_add(
 	    accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_c);
 
 	/* Ignore button */
 	d->ignore_btn = w = GUIButtonPixmapLabelH(
@@ -931,9 +912,10 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'i', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_i, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_i);
 
 	/* Retry button */
 	d->retry_btn = w = GUIButtonPixmapLabelH(
@@ -968,9 +950,10 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'r', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_r, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
+	GUIButtonLabelUnderline(w, GDK_r);
 
 	/* Abort button */
 	d->abort_btn = w = GUIButtonPixmapLabelH(
@@ -1008,10 +991,10 @@ gint CDialogInit(void)
 	 * taken by "Yes To All"
 	 */
 	gtk_accel_group_add(
-	    accelgrp, 'b', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_b, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
-
+	GUIButtonLabelUnderline(w, GDK_b);
 
 	/* Help button */
 	d->help_btn = w = GUIButtonPixmapLabelH(
@@ -1046,7 +1029,7 @@ gint CDialogInit(void)
 	    GTK_SIGNAL_FUNC(CDialogButtonCB), d
 	);
 	gtk_accel_group_add(
-	    accelgrp, 'h', 0, GTK_ACCEL_VISIBLE,
+	    accelgrp, GDK_h, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
 	gtk_accel_group_add(
@@ -1061,7 +1044,7 @@ gint CDialogInit(void)
 	    accelgrp, GDK_Arabic_question_mark, 0, GTK_ACCEL_VISIBLE,
 	    GTK_OBJECT(w), "clicked"
 	);
-
+	GUIButtonLabelUnderline(w, GDK_h);
 
 	return(0);
 }
@@ -1072,9 +1055,8 @@ gint CDialogInit(void)
 void CDialogSetStyle(GtkRcStyle *rc_style)
 {
 	GtkWidget *w;
-	cdialog_struct *d = &cdialog;
-
-	if(!d->initialized)
+	CDlg *d = cdlg;
+	if(d == NULL)
 	    return;
 
 	w = d->toplevel;
@@ -1100,9 +1082,8 @@ void CDialogSetStyle(GtkRcStyle *rc_style)
  */
 void CDialogSetTransientFor(GtkWidget *w)
 {
-	cdialog_struct *d = &cdialog;
-
-	if(!d->initialized)
+	CDlg *d = cdlg;
+	if(d == NULL)
 	    return;
 
 	if(d->toplevel != NULL)
@@ -1141,10 +1122,11 @@ void CDialogSetTransientFor(GtkWidget *w)
  */
 gboolean CDialogIsQuery(void)
 {
-	if(block_loop_level > 0)
-	    return(TRUE);
-	else
+	CDlg *d = cdlg;
+	if(d == NULL)
 	    return(FALSE);
+
+	return((d->block_loop_level > 0) ? TRUE : FALSE);
 }
 
 /*
@@ -1153,15 +1135,19 @@ gboolean CDialogIsQuery(void)
  */
 void CDialogBreakQuery(void)
 {
-	response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	CDlg *d = cdlg;
+	if(d == NULL)
+	    return;
 
-	/* Break out of any blocking loops */
-	while(block_loop_level > 0)
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+
+	/* Break out of all main loops */
+	while(d->block_loop_level > 0)
 	{
 	    gtk_main_quit();
-	    block_loop_level--;
+	    d->block_loop_level--;
 	}
-	block_loop_level = 0;
+	d->block_loop_level = 0;
 }
 
 /*
@@ -1169,7 +1155,7 @@ void CDialogBreakQuery(void)
  */
 GtkWidget *CDialogGetToplevel(void)
 {
-	cdialog_struct *d = &cdialog;
+	CDlg *d = cdlg;
 	return((d != NULL) ? d->toplevel : NULL);
 }
 
@@ -1181,7 +1167,7 @@ GtkWidget *CDialogGetToplevel(void)
  *	The button in default_button will be grabbed and set as default.
  */
 static void CDialogRemapButtons(
-	cdialog_struct *d,
+	CDlg *d,
 	cdialog_btn_flags show_buttons,		/* Any of CDIALOG_BTNFLAG_* */
 	cdialog_btn_flags default_button	/* One of CDIALOG_BTNFLAG_* */
 )
@@ -1329,19 +1315,17 @@ gint CDialogGetResponse(
 )
 {
 	GtkWidget *w, *toplevel;
-	cdialog_struct *d = &cdialog;
-
-
-	/* Already waiting for user response? */
-	if(block_loop_level > 0)
+	CDlg *d = cdlg;
+	if(d == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
-	if(!d->initialized)
-	    return(response_code);
+	/* Already waiting for user response? */
+	if(d->block_loop_level > 0)
+	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	/* Reset values */
-	response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	block_loop_level = 0;
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	d->block_loop_level = 0;
 
 	toplevel = d->toplevel;
 
@@ -1408,26 +1392,26 @@ gint CDialogGetResponse(
 	CDialogMap();
 
 	/* Block until user response */
-	block_loop_level++;
+	d->block_loop_level++;
 	gtk_main();
 
 	/* Unmap the CDialog */
 	CDialogUnmap();
 
-	/* Break out of an additional blocking loops */
-	while(block_loop_level > 0)
+	/* Break out of all main loops */
+	while(d->block_loop_level > 0)
 	{
 	    gtk_main_quit();
-	    block_loop_level--;
+	    d->block_loop_level--;
 	}
-	block_loop_level = 0;
+	d->block_loop_level = 0;
 
-	return(response_code);
+	return(d->response_code);
 }
 
 /*
- *      Same as CDialogGetResponse() except custom icon data can be set
- *	instead.
+ *      Same as CDialogGetResponse() except that the icon is set by
+ *	the specified icon data.
  */
 gint CDialogGetResponseIconData(
 	const gchar *title,
@@ -1439,19 +1423,17 @@ gint CDialogGetResponseIconData(
 )
 {
 	GtkWidget *w, *toplevel;
-	cdialog_struct *d = &cdialog;
-
-
-	/* Already waiting for user response? */
-	if(block_loop_level > 0)
+	CDlg *d = cdlg;
+	if(d == NULL)
 	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
-	if(!d->initialized)
-	    return(response_code);
+	/* Already waiting for user response? */
+	if(d->block_loop_level > 0)
+	    return(CDIALOG_RESPONSE_NOT_AVAILABLE);
 
 	/* Reset values */
-	response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-	block_loop_level = 0;
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
+	d->block_loop_level = 0;
 
 	toplevel = d->toplevel;
 
@@ -1516,21 +1498,21 @@ gint CDialogGetResponseIconData(
 	CDialogMap();
 
 	/* Block until user response */
-	block_loop_level++;
+	d->block_loop_level++;
 	gtk_main();
 
 	/* Unmap the CDialog */
 	CDialogUnmap();
 
-	/* Break out of an additional blocking loops */
-	while(block_loop_level > 0)
+	/* Break out of all main loops */
+	while(d->block_loop_level > 0)
 	{
 	    gtk_main_quit();
-	    block_loop_level--;
+	    d->block_loop_level--;
 	}
-	block_loop_level = 0;
+	d->block_loop_level = 0;
 
-	return(response_code);
+	return(d->response_code);
 }
 
 /*
@@ -1548,13 +1530,14 @@ gint CDialogGetResponseFile(
 {
 	gint response;
 	gchar *buf;
-	FILE *fp = !STRISEMPTY(filename) ? FOpen(filename, "rb") : NULL;
+	FILE *fp = !STRISEMPTY(filename) ?
+	    FOpen((const char *)filename, "rb") : NULL;
 	if(fp == NULL)
 	{
 	    /* Failed to open file */
 	    if(!STRISEMPTY(filename))
 		buf = g_strdup_printf(
-"Unable to open file:\n\
+"Unable to open the file:\n\
 \n\
     %s\n",
 		    filename
@@ -1569,7 +1552,7 @@ gint CDialogGetResponseFile(
 
 	    buf = (gchar *)g_malloc(buf_len * sizeof(gchar));
 	    if(buf != NULL)
-		bytes_read = fread(buf, sizeof(gchar), buf_len, fp);
+		bytes_read = (gint)fread(buf, sizeof(gchar), (size_t)buf_len, fp);
 	    else
 		bytes_read = 0;
 	    if(bytes_read < 0)
@@ -1603,7 +1586,7 @@ gint CDialogGetResponseFile(
  */
 void CDialogMap(void)
 {
-	cdialog_struct *d = &cdialog;
+	CDlg *d = cdlg;
 	GtkWidget *w = (d != NULL) ? d->toplevel : NULL;
 	if(w == NULL)
 	    return;
@@ -1616,7 +1599,7 @@ void CDialogMap(void)
  */
 void CDialogUnmap(void)
 {
-	cdialog_struct *d = &cdialog;
+	CDlg *d = cdlg;
 	GtkWidget *w = (d != NULL) ? d->toplevel : NULL;
 	if(w == NULL)
 	    return;
@@ -1629,52 +1612,47 @@ void CDialogUnmap(void)
  */
 void CDialogShutdown(void)
 {
-	cdialog_struct *d = &cdialog;
+	CDlg *d = cdlg;
+	if(d == NULL)
+	    return;
 
+	d->response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
 
-	/* Reset globals */
-	response_code = CDIALOG_RESPONSE_NOT_AVAILABLE;
-
-	/* Break out of an additional blocking loops */
-	while(block_loop_level > 0)
+	/* Break out of all main loops */
+	while(d->block_loop_level > 0)
 	{
 	    gtk_main_quit();
-	    block_loop_level--;
+	    d->block_loop_level--;
 	}
-	block_loop_level = 0;
+	d->block_loop_level = 0;
 
-	/* Unmap dialog */
+	/* Unmap Dialog */
 	CDialogUnmap();
 
-	/* Is dialog initialized? */
-	if(d->initialized)
-	{
-	    /* Begin destroying dialog widgets */
+	/* Begin destroying widgets */
+	GTK_WIDGET_DESTROY(d->icon_pm)
+	GTK_WIDGET_DESTROY(d->label)
+	GTK_WIDGET_DESTROY(d->label_hbox)
+	GTK_WIDGET_DESTROY(d->help_icon_pm)
+	GTK_WIDGET_DESTROY(d->help_label)
+	GTK_WIDGET_DESTROY(d->help_vbox)
 
-	    GTK_WIDGET_DESTROY(d->icon_pm)
-	    GTK_WIDGET_DESTROY(d->label)
-	    GTK_WIDGET_DESTROY(d->label_hbox)
-	    GTK_WIDGET_DESTROY(d->help_icon_pm)
-	    GTK_WIDGET_DESTROY(d->help_label)
-	    GTK_WIDGET_DESTROY(d->help_vbox)
+	GTK_WIDGET_DESTROY(d->ok_btn)
+	GTK_WIDGET_DESTROY(d->yes_btn)
+	GTK_WIDGET_DESTROY(d->yes_to_all_btn)
+	GTK_WIDGET_DESTROY(d->no_btn)
+	GTK_WIDGET_DESTROY(d->cancel_btn)
+	GTK_WIDGET_DESTROY(d->ignore_btn)
+	GTK_WIDGET_DESTROY(d->retry_btn)
+	GTK_WIDGET_DESTROY(d->abort_btn)
+	GTK_WIDGET_DESTROY(d->help_btn)
 
-	    GTK_WIDGET_DESTROY(d->ok_btn)
-	    GTK_WIDGET_DESTROY(d->yes_btn)
-	    GTK_WIDGET_DESTROY(d->yes_to_all_btn)
-	    GTK_WIDGET_DESTROY(d->no_btn)
-	    GTK_WIDGET_DESTROY(d->cancel_btn)
-	    GTK_WIDGET_DESTROY(d->ignore_btn)
-	    GTK_WIDGET_DESTROY(d->retry_btn)
-	    GTK_WIDGET_DESTROY(d->abort_btn)
-	    GTK_WIDGET_DESTROY(d->help_btn)
+	GTK_WIDGET_DESTROY(d->button_hbox)
+	GTK_WIDGET_DESTROY(d->main_vbox)
+	GTK_WIDGET_DESTROY(d->toplevel)
 
-	    GTK_WIDGET_DESTROY(d->button_hbox)
-	    GTK_WIDGET_DESTROY(d->main_vbox)
-	    GTK_WIDGET_DESTROY(d->toplevel)
+	GTK_ACCEL_GROUP_UNREF(d->accelgrp)
 
-	    GTK_ACCEL_GROUP_UNREF(d->accelgrp)
-	}
-
-	/* Clear CDialog structure */
-	memset(d, 0x00, sizeof(cdialog_struct));
+	cdlg = NULL;
+	g_free(d);
 }
