@@ -6,7 +6,7 @@
 
 #include "../include/os.h"
 
-#ifdef __MSW__
+#if defined(_WIN32)
 # include <io.h>	/* Needed by _findfirst(), _findnext(), etc */
 #else
 # include <unistd.h>
@@ -16,11 +16,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#ifndef USE_GETDENTS
-# ifndef __MSW__
+#if !defined(USE_GETDENTS) && !defined(_WIN32)
 # include <dirent.h>
-# endif
-#endif /* not USE_GETDENTS */
+#endif
 
 #if defined(__linux__)
 # include <linux/limits.h>
@@ -99,43 +97,37 @@ int FILEHASEXTENSION(const char *filename)
 	    return(1);
 }
 
+/*
+ *	Checks if the specified path is an absolute path.
+ */
 int ISPATHABSOLUTE(const char *path)
 {
-#ifdef __MSW__
-	char *strptr;
+#if defined(_WIN32)
+	char *s;
 
-	if(STRISEMPTY(path))
+	if(path == NULL)
 	    return(0);
 
-	/* Has drive notation? */
-	strptr = strchr(path, ':');
-	if(strptr == NULL)
+	/* Has "X:" drive notation? */
+	if((path[0] != '\0') ? (path[1] == ':') : 0)
 	{
-	    /* No drive notation, check if first char is a '\\' */
-#if defined(__cplusplus) || defined(c_plusplus)
-	    while(ISBLANK(*path))
-#else
-	    while(ISBLANK((int)(*path)))
-#endif
-		path++;
-
-	    return(*path == '\\');
+            /* Has drive notation, check if first char past the drive
+	     * notation is a DIR_DELIMINATOR
+	     */
+            return(path[2] == DIR_DELIMINATOR);
 	}
 	else
 	{
-	    /* Has drive notation, check if first char past : is a '\\' */
-	    return((*(strptr + 1)) == '\\');
+	    /* No drive notation, check if first char is a '\\' */
+	    while(ISBLANK(*path))
+		path++;
+	    return(*path == DIR_DELIMINATOR);
 	}
 #else
 	if(path == NULL)
 	    return(0);
 
-	// Dan S: typecast is due to const.
-#if defined(__cplusplus) || defined(c_plusplus)
-	while(ISBLANK(reinterpret_cast<char>(*path)))
-#else
 	while(ISBLANK(*path))
-#endif
 	    path++;
 
 	return(*path == DIR_DELIMINATOR);
@@ -147,13 +139,10 @@ int ISPATHABSOLUTE(const char *path)
  */
 int NUMDIRCONTENTS(const char *path)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	int i, total = 0;
-	char **strv;
 	const char *s;
-
-
-	strv = GetDirEntNames(path);
+	char **strv = GetDirEntNames(path);
 	if(strv == NULL)
 	    return(total);
 
@@ -182,7 +171,6 @@ int NUMDIRCONTENTS(const char *path)
 	const char *s;
 	struct dirent *de;
 
-
 	if(path == NULL)
 	    return(total);
 
@@ -195,7 +183,7 @@ int NUMDIRCONTENTS(const char *path)
 	while(1)
 	{
 	    /* Get next directory entry */
-	    de = (struct dirent *)readdir(dir);
+	    de = readdir(dir);
 	    if(de == NULL)
 		break;
 
@@ -274,12 +262,11 @@ int ISPATHDIR(const char *path)
 
 int ISLPATHDIR(const char *path)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	return(ISPATHDIR(path));
 #else
 	struct stat stat_buf;
 
-
 	if(STRISEMPTY(path))
 	    return(0);
 
@@ -293,25 +280,24 @@ int ISLPATHDIR(const char *path)
 
 int ISPATHEXECUTABLE(const char *path)
 {
-#ifdef __MSW__
-	char *strptr;
-
+#if defined(_WIN32)
+	char *s;
 
 	if(STRISEMPTY(path))
 	    return(0);
 
-	strptr = strrchr(path, '.');
-	if(strptr == NULL)
+	s = strrchr(path, '.');
+	if(s == NULL)
 	    return(0);
 	else
-	    strptr++;
+	    s++;
 
 	/* Check known MSW extensions for being executeable */
-	if(!strcasecmp(strptr, "exe"))
+	if(!strcasecmp(s, "exe"))
 	    return(1);
-	else if(!strcasecmp(strptr, "bat"))
+	else if(!strcasecmp(s, "bat"))
 	    return(1);
-	else if(!strcasecmp(strptr, "com"))
+	else if(!strcasecmp(s, "com"))
 	    return(1);
 	else
 	    return(0);
@@ -393,7 +379,7 @@ int rmkdir(const char *path, mode_t m)
 
 	    if(stat(full_path, &stat_buf))
 	    {
-#if defined(__MSW__)
+#ifdef _WIN32
 		if(mkdir(full_path))
 		{
 		    free(full_path);
@@ -426,20 +412,19 @@ int rmkdir(const char *path, mode_t m)
  */
 char *PathSubHome(const char *path)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	static char rtn_path[PATH_MAX];
 
 	if(STRISEMPTY(path))
 	    return(NULL);
 
-	strncpy(rtn_path, path, PATH_MAX);
-	rtn_path[PATH_MAX - 1] = '\0';
+	strncpy(rtn_path, path, sizeof(rtn_path));
+	rtn_path[sizeof(rtn_path) - 1] = '\0';
 
 	return(rtn_path);
 #else
 	static char rtn_path[PATH_MAX];
 
-
 	if(STRISEMPTY(path))
 	    return(NULL);
 
@@ -448,7 +433,7 @@ char *PathSubHome(const char *path)
 	 */
 	if(*path == '~')
 	{
-	    int m = PATH_MAX;
+	    size_t m = sizeof(rtn_path);
 	    const char *src = path + 1;
 	    const char *home = getenv("HOME");
 
@@ -468,12 +453,12 @@ char *PathSubHome(const char *path)
 	    if(m > 0)
 		strncat(rtn_path, src, m);
 
-	    rtn_path[PATH_MAX - 1] = '\0';
+	    rtn_path[sizeof(rtn_path) - 1] = '\0';
 	}
 	else
 	{
-	    strncpy(rtn_path, path, PATH_MAX);
-	    rtn_path[PATH_MAX - 1] = '\0';
+	    strncpy(rtn_path, path, sizeof(rtn_path));
+	    rtn_path[sizeof(rtn_path) - 1] = '\0';
 	}
 
 	return(rtn_path);
@@ -597,7 +582,7 @@ char **GetDirEntNames2(const char *parent, int *total)
 
 char **GetDirEntNames2(const char *parent, int *total)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	long ffh;		/* Find file handle */
 	struct _finddata_t d;	/* Find data return structure */
 	char prev_cwd[PATH_MAX];
@@ -607,16 +592,20 @@ char **GetDirEntNames2(const char *parent, int *total)
 	    *total = 0;
 
 	/* Record previous current working dir */
-	getcwd(prev_cwd, PATH_MAX);
-	prev_cwd[PATH_MAX - 1] = '\0';
+	if(getcwd(prev_cwd, sizeof(prev_cwd)) != NULL)
+	    prev_cwd[sizeof(prev_cwd) - 1] = '\0';
+	else
+	    *prev_cwd = '\0';
 
 	/* Change to parent dir */
-	chdir(parent);
+	if(parent != NULL)
+	    chdir(parent);
 
 	/* Find first file in specified directory */
 	ffh = _findfirst("*", &d);
 	if(ffh == -1L)
 	{
+	    chdir(prev_cwd);
 	    return(NULL);
 	}
 	else
@@ -629,6 +618,7 @@ char **GetDirEntNames2(const char *parent, int *total)
 	    if(rtn_names == NULL)
 	    {
 		_findclose(ffh);
+		chdir(prev_cwd);
 		return(NULL);
 	    }
 
@@ -642,15 +632,17 @@ char **GetDirEntNames2(const char *parent, int *total)
 		if(rtn_names == NULL)
 		{
 		    _findclose(ffh);
+		    chdir(prev_cwd);
 		    return(NULL);
 		}
 
-		rtn_names[i] = StringCopyAlloc(d.name);
+		rtn_names[i] = strdup(d.name);
 		i++;
 	    }
 
 	    /* Close find file handle and its resources */
 	    _findclose(ffh);
+	    chdir(prev_cwd);
 
 	    /* Allocate last pointer to be NULL */
 	    rtn_names = (char **)realloc(rtn_names, (i + 1) * sizeof(char *));
@@ -721,7 +713,7 @@ char **GetDirEntNames2(const char *parent, int *total)
 	    *total = i;
 
 	return(rtn_names);
-#endif	/* NOT __MSW__ */
+#endif	/* NOT _WIN32 */
 }
 #endif /* USE_GETDENTS */
 
@@ -745,7 +737,7 @@ char **GetDirEntNames(const char *parent)
 char *ChangeDirRel(const char *cpath, const char *npath)
 {
 	int len;
-	char *rtn_str, *strptr;
+	char *rtn_str, *s;
 
 
 	/* If both cpath and npath are NULL, return allocated cwd */
@@ -855,17 +847,17 @@ char *ChangeDirRel(const char *cpath, const char *npath)
 	/* npath is a relative notation */
 
 	/* Prefix paths */
-	strptr = PrefixPaths(cpath, npath);
-	if(strptr == NULL)
+	s = PrefixPaths(cpath, npath);
+	if(s == NULL)
 	    return(NULL);
 
 	/* Allocate return string */
-	len = STRLEN(strptr);
+	len = STRLEN(s);
 	rtn_str = (char *)malloc((len + 1) * sizeof(char));
 	if(rtn_str == NULL)
 	    return(NULL);
 
-	strncpy(rtn_str, strptr, len);
+	strncpy(rtn_str, s, len);
 	rtn_str[len] = '\0';
 
 
@@ -877,72 +869,62 @@ char *ChangeDirRel(const char *cpath, const char *npath)
 }
 
 /*
- *	Strips the pointed storage path of its absolute path,
+ *	Strips the specified absolute path of its absolute path,
  *	leaving it with just the final destination name.
  */
 void StripAbsolutePath(char *path)
 {
-	char *strptr1, *strptr2;
-
+	char *s1, *s2;
 
 	if(path == NULL)
 	    return;
 
-	if((*path) != DIR_DELIMINATOR)
+	if(*path != DIR_DELIMINATOR)
 	    return;
 
-	strptr1 = path;
+	s1 = path;
 
 	/* Seek to end */
-	while((*strptr1) != '\0')
-	    strptr1++;
+	while(*s1 != '\0')
+	    s1++;
 
 	/* Seek back, skipping tailing DIR_DELIMINATOR chars */
-	strptr1--;
-	if(strptr1 < path)
-	    strptr1 = path;
-	while((strptr1 > path) &&
-	      (*strptr1 == DIR_DELIMINATOR)
-	)
-	    strptr1--;
+	s1--;
+	if(s1 < path)
+	    s1 = path;
+	while((s1 > path) && (*s1 == DIR_DELIMINATOR))
+	    s1--;
 
 	/* Seek back untill a DIR_DELIMINATOR char */
-	if(strptr1 < path)
-	    strptr1 = path;
-	while((strptr1 > path) &&
-	      ((*strptr1) != DIR_DELIMINATOR)
-	)
-	    strptr1--;
+	if(s1 < path)
+	    s1 = path;
+	while((s1 > path) && (*s1 != DIR_DELIMINATOR))
+	    s1--;
 
-	strptr1++;      /* Go forward one char */
+	s1++;      /* Go forward one char */
 
-	if(strptr1 < path)
-	    strptr1 = path;
+	if(s1 < path)
+	    s1 = path;
 
 	/* Copy child to beginning */
-	strptr2 = path;
-	while((*strptr1) != '\0')
-	{
-	    (*strptr2) = (*strptr1);
+	s2 = path;
+	while(*s1 != '\0')
+	    *s2++ = *s1++;
+	*s2 = '\0';
 
-	    strptr1++;
-	    strptr2++;
-	}
-	(*strptr2) = '\0';
-
-	/* Make sure path contains atleast DIR_DELIMINATOR */
-	if((*path) == '\0')
+	/* Make sure the path contains atleast toplevel */
+	if(*path == '\0')
 	{
 	    path[0] = DIR_DELIMINATOR;
 	    path[1] = '\0';
 	}
-
-	return;
 }
 
 /*
- *	Checks if parent is under the specified path, if it
- *	is then it will be removed. Example:
+ *	Checks if parent is under the specified path, if it is then it
+ *	will be removed.
+ *
+ *	Example:
  *
  *	path = "/var/spool/mail"
  *	parent = "/var"
@@ -951,18 +933,13 @@ void StripAbsolutePath(char *path)
  */
 void StripParentPath(char *path, const char *parent)
 {
-	char *strptr;
+	char *s;
 
-
-	if((path == NULL) ||
-	   (parent == NULL)
-	)
+	if((path == NULL) || (parent == NULL))
 	    return;
 
 	/* Both given paths must be absolute */
-	if(!ISPATHABSOLUTE(path) ||
-	   !ISPATHABSOLUTE(parent)
-	)
+	if(!ISPATHABSOLUTE(path) || !ISPATHABSOLUTE(parent))
 	    return;
 
 	if(!COMPARE_PARENT_PATHS(path, parent))
@@ -972,20 +949,18 @@ void StripParentPath(char *path, const char *parent)
 	substr(path, parent, "");
 
 	/* Need to remove any prefixing DIR_DELIMINATOR characters */
-	while((*path) == DIR_DELIMINATOR)
+	while(*path == DIR_DELIMINATOR)
 	{
-	    strptr = path;
-	    while(*strptr != '\0')
-		*strptr++ = *(strptr + 1);
+	    s = path;
+	    while(*s != '\0')
+		*s++ = *(s + 1);
 	}
 
 	/* If path is empty, it implies the parent and path were
-	 * the same.
+	 * the same
 	 */
 	if(*path == '\0')
 	    strcpy(path, parent);
-
-	return;
 }
 
 /*
@@ -999,68 +974,57 @@ void StripParentPath(char *path, const char *parent)
  */
 char *PrefixPaths(const char *parent, const char *child)
 {
-	char *strptr1, *strend;
-	const char *strptr2;
+	char *s, *s_end;
+	const char *s2;
 	static char rtn_path[PATH_MAX];
 
-
-	if((parent == NULL) ||
-	   (child == NULL) ||
-	   (parent == child)
-	)
+	if((parent == NULL) || (child == NULL) || (parent == child))
 	    return("/");
 
 	/* If child is absolute, copy child and return */
-	if((*child) == DIR_DELIMINATOR)
+	if(*child == DIR_DELIMINATOR)
 	{
-	    strncpy(rtn_path, child, PATH_MAX);
-	    rtn_path[PATH_MAX - 1] = '\0';
-
+	    strncpy(rtn_path, child, sizeof(rtn_path));
+	    rtn_path[sizeof(rtn_path) - 1] = '\0';
 	    return(rtn_path);
 	}
 
-	/* Calculate strend */
-	strend = rtn_path + PATH_MAX;
+	/* Get the end of rtn_path */
+	s_end = rtn_path + sizeof(rtn_path);
 
+	/* Copy the parent to rtn_path */
+	strncpy(rtn_path, parent, sizeof(rtn_path));
+	rtn_path[sizeof(rtn_path) - 1] = '\0';
 
-	/* Copy parent */
-	strncpy(rtn_path, parent, PATH_MAX);
-	rtn_path[PATH_MAX - 1] = '\0';
+	/* Seek s to end of parent path in rtn_path */
+	s = rtn_path;
+	while(*s != '\0')
+	    s++;
 
-	/* Seek to end of rtn_path */
-	strptr1 = rtn_path;
-	while((*strptr1) != '\0')
-	    strptr1++;
-
-	/* Insert deliminating DIR_DELIMINATOR char */
-	if(strptr1 > rtn_path)
+	/* Insert deliminator to rtn_path */
+	if(s > rtn_path)
 	{
-	    if(*(strptr1 - 1) != DIR_DELIMINATOR)
+	    /* Does the parent portion of rtn_path does not already
+	     * have a tailing deliminator?
+	     */
+	    if(*(s - 1) != DIR_DELIMINATOR)
 	    {
-		(*strptr1) = DIR_DELIMINATOR;
-		strptr1++;
+		*s++ = DIR_DELIMINATOR;
 	    }
 	}
 	else
 	{
-	    strptr1 = rtn_path;
+	    s = rtn_path;
 	}
 
 	/* Copy child */
-	strptr2 = child;
-	while((strptr1 < strend) &&
-	      (*strptr2 != '\0')
-	)
-	{
-	    *strptr1 = *strptr2;
-
-	    strptr1++;
-	    strptr2++;
-	}
-	if(strptr1 < strend)
-	    *strptr1 = '\0';
+	s2 = child;
+	while((s < s_end) && (*s2 != '\0'))
+	    *s++ = *s2++;
+	if(s < s_end)
+	    *s = '\0';
 	else
-	    rtn_path[PATH_MAX - 1] = '\0';
+	    rtn_path[sizeof(rtn_path) - 1] = '\0';
 
 	/* Make sure rtn_path contains atleast "/" */
 	if(*rtn_path == '\0')
@@ -1082,22 +1046,23 @@ char *PrefixPaths(const char *parent, const char *child)
  */
 char *GetAllocLinkDest(const char *link)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	return(NULL);
 #else
 	int bytes_read;
 	char *dest;
-	struct stat stat_buf;
-
+	struct stat lstat_buf;
 
 	if(link == NULL)
 	    return(NULL);
-	if(lstat(link, &stat_buf))
+	if(lstat(link, &lstat_buf))
 	    return(NULL);
-	if(!S_ISLNK(stat_buf.st_mode))
+#ifdef S_ISLNK
+	if(!S_ISLNK(lstat_buf.st_mode))
 	    return(NULL);
+#endif
 
-	/* Allocate dest buffer */
+	/* Allocate link destination buffer */
 	dest = (char *)calloc(1, (PATH_MAX + NAME_MAX + 1) * sizeof(char));
 	if(dest == NULL)
 	    return(NULL);
@@ -1116,12 +1081,11 @@ char *GetAllocLinkDest(const char *link)
 	if(bytes_read < 0)
 	    bytes_read = 0;
 
-	/* Must NULL terminate */
+	/* Null terminate */
 	dest[bytes_read] = '\0';
 
-
 	return(dest);
-#endif	/* NOT __MSW__ */
+#endif	/* NOT _WIN32 */
 }
 
 
@@ -1367,7 +1331,7 @@ int FileCountLines(const char *filename)
  */
 int DirHasSubDirs(const char *path)
 {
-#ifdef __MSW__
+#if defined(_WIN32)
 	return(0);
 #else
 	int status = 0;
@@ -1427,7 +1391,7 @@ int DirHasSubDirs(const char *path)
 	closedir(dir);
 
 	return(status);
-#endif	/* NOT __MSW__ */
+#endif	/* NOT _WIN32 */
 }
 
 
@@ -1454,7 +1418,7 @@ char *GetParentDir(const char *path)
 	    return(parent);
 
 	/* Strip tailing deliminators */
-#ifdef __MSW__
+#ifdef _WIN32
 	while(s >= (parent + 3))
 #else
 	while(s >= (parent + 1))
@@ -1468,7 +1432,7 @@ char *GetParentDir(const char *path)
 	}
 
 	/* Get parent */
-#ifdef __MSW__
+#ifdef _WIN32
 	if(s >= (parent + 3))
 	    *s = '\0';
 	else
@@ -1488,24 +1452,24 @@ char *GetParentDir(const char *path)
  */
 void StripPath(char *path)
 {
-	char *strptr;
+	char *s;
 
 
 	if(path == NULL)
 	    return;
 
-	strptr = strrchr(path, DIR_DELIMINATOR);
-	if(strptr != NULL)
+	s = strrchr(path, DIR_DELIMINATOR);
+	if(s != NULL)
 	{
-	    while((*(strptr + 1) == '\0') &&
-		  (strptr > path)
+	    while((*(s + 1) == '\0') &&
+		  (s > path)
 	    )
 	    {
-		if(*strptr != DIR_DELIMINATOR)
+		if(*s != DIR_DELIMINATOR)
 		    break;
 
-		*strptr = '\0';
-		strptr--;
+		*s = '\0';
+		s--;
 	    }
 	}
 }
@@ -1527,10 +1491,8 @@ void SimplifyPath(char *path)
 
 	was_absolute_path = ISPATHABSOLUTE(path);
 
-	/* Seek to first path compoent */
-	s = path;
-	while(*s == DIR_DELIMINATOR)
-	    s++;
+	/* Seek s to first path compoent */
+	for(s = path; *s == DIR_DELIMINATOR; s++);
 
 	while(*s != '\0')
 	{
@@ -1635,16 +1597,15 @@ int CopyObject(
 	int (*comferm_func)(const char *, const char *)
 )
 {
-	int c;
 	FILE *tar_fp, *src_fp;
+	int c;
 	struct stat stat_buf;
 
-
 	if((target == NULL) || (source == NULL))
 	    return(-1);
 
 	/* Check if target exists */
-#ifdef __MSW__
+#ifdef _WIN32
 	if(!stat(target, &stat_buf))
 #else
 	if(!lstat(target, &stat_buf))
