@@ -31,7 +31,7 @@ gchar *EditorDNDParseURL(
 
 /* Inserting to target editor routines */
 static GtkCTreeNode *EditorDNDItemAdd(
-	editor_struct *editor, editor_item_struct *item_ptr,
+	editor_struct *editor, editor_item_struct *item,
 	GtkCTreeNode *parent, GtkCTreeNode *sibling
 );
 static void EditorDNDItemListAdd(
@@ -62,7 +62,7 @@ static void EditorDNDViewerIndexItemLoad(
 
 /* DND handling */
 void EditorDNDSetIcon(
-	editor_struct *editor, editor_item_struct *item_ptr
+	editor_struct *editor, editor_item_struct *item
 );
 void EditorDNDDataRequestCB(
 	GtkWidget *widget, GdkDragContext *dc,
@@ -218,46 +218,40 @@ gchar *EditorDNDParseURL(
  *	Returns the newly created node or NULL on failure.
  */
 static GtkCTreeNode *EditorDNDItemAdd(
-	editor_struct *editor, editor_item_struct *item_ptr,
+	editor_struct *editor, editor_item_struct *item,
 	GtkCTreeNode *parent, GtkCTreeNode *sibling
 )
 {
+	gchar *text[1]; 
 	GtkCTreeNode *branch;
-	GtkCTree *ctree;
-	gchar *text[1];
-	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 	GdkPixmap *closed_p = NULL, *opened_p = NULL;
 	GdkBitmap *closed_m = NULL, *opened_m = NULL;
-
-
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	ctree = (GtkCTree *)editor->layout_ctree;
-
+	medit_core_struct *core_ptr = MEDIT_CORE(editor->core_ptr);
+	GtkCTree *ctree = (GtkCTree *)editor->layout_ctree;
 	if((core_ptr == NULL) || (ctree == NULL))
 	{
-	    EditorItemDelete(item_ptr);
+	    EditorItemDelete(item);
 	    return(NULL);
 	}
 
 	pixmaps_list = &core_ptr->pixmaps_list;
 
-
 	/* Reset name for new branch, it'll be picked below */
 	text[0] = NULL;
 
 	/* Item data valid? */
-	if(item_ptr != NULL)
+	if(item != NULL)
 	{
 	    /* Handle by item data type */
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case EditorItemTypeFile:
 		closed_p = pixmaps_list->manual_closed_20x20;
 		closed_m = pixmaps_list->manual_closed_20x20_mask;
 		opened_p = pixmaps_list->manual_opened_20x20;
 		opened_m = pixmaps_list->manual_opened_20x20_mask;
-		text[0] = item_ptr->file_name;
+		text[0] = item->name;
 		break;
 
 	      case EditorItemTypeHeader:
@@ -273,7 +267,7 @@ static GtkCTreeNode *EditorDNDItemAdd(
 		closed_m = pixmaps_list->manpage_section_20x20_mask;
 		opened_p = closed_p;
 		opened_m = closed_m;
-		text[0] = item_ptr->section_name;
+		text[0] = item->section_name;
 		break;
 	    }
 	}
@@ -287,7 +281,7 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	    MEDIT_LIST_ICON_TEXT_SPACING,
 	    closed_p, closed_m,
 	    opened_p, opened_m,
-	    (item_ptr != NULL) ? item_ptr->is_leaf : TRUE,	/* Is leaf */
+	    (item != NULL) ? item->is_leaf : TRUE,	/* Is leaf */
 	    FALSE		/* Expanded */
 	);
 
@@ -296,16 +290,15 @@ static GtkCTreeNode *EditorDNDItemAdd(
 	 * pointers for editor and ctree may not match the original ones
 	 * so that is why we need to update them.
 	 */
-	if(item_ptr != NULL)
+	if(item != NULL)
 	{
-	    item_ptr->editor_ptr = (void *)editor;
-
-	    item_ptr->ctree = ctree;
-	    item_ptr->parent = parent;
-	    item_ptr->this_branch = branch;
+	    item->editor = editor;
+	    item->ctree = ctree;
+	    item->parent = parent;
+	    item->this_branch = branch;
 
 	    /* Item of type file? */
-	    if(item_ptr->type == EditorItemTypeFile)
+	    if(item->type == EditorItemTypeFile)
 	    {
 		/* Need to add this to the editor's layout_trunk list */
 
@@ -320,9 +313,9 @@ g_printerr("Cannot copy item of type EditorItemTypeFile yet.\n");
 	/* Set item data to newly inserted branch */
 	EditorBranchSetData(
 	    ctree, branch,
-	    item_ptr, EditorItemDestroyCB
+	    item, EditorItemDestroyCB
 	);   
-	item_ptr = NULL;
+	item = NULL;
 
 	/* Mark new branch's item data as having changes */
 	EditorItemSetToplevelHasChanges(
@@ -479,13 +472,12 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	GtkCTreeNode *src_branch	/* From source editor */
 )
 {
-	editor_item_struct *item_ptr, *src_item_ptr;
-	GtkCTreeNode *new_branch;
-	GtkCTreeRow *branch_row;
 	gchar *text[1];
 	GdkPixmap *closed_p = NULL, *opened_p = NULL;
 	GdkBitmap *closed_m = NULL, *opened_m = NULL;
-
+	GtkCTreeNode *new_branch;
+	GtkCTreeRow *branch_row; 
+	editor_item_struct *item, *src_item;
 
 	if(src_branch == NULL)
 	    return(NULL);
@@ -493,24 +485,24 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	branch_row = GTK_CTREE_ROW(src_branch);
 
 	/* Get source item pointer from source branch */
-	src_item_ptr = EditorBranchGetData(
+	src_item = EditorBranchGetData(
 	    src_ctree, src_branch
 	);
 
 	text[0] = NULL;
 
 	/* Item data valid? */
-	if(src_item_ptr != NULL)
+	if(src_item != NULL)
 	{
 	    /* Handle by item data type */
-	    switch(src_item_ptr->type)
+	    switch(src_item->type)
 	    {
 	      case EditorItemTypeFile:
 		closed_p = pixmaps_list->manual_closed_20x20;
 		closed_m = pixmaps_list->manual_closed_20x20_mask;
 		opened_p = pixmaps_list->manual_opened_20x20;
 		opened_m = pixmaps_list->manual_opened_20x20_mask;
-		text[0] = src_item_ptr->file_name;
+		text[0] = src_item->name;
 		break;
 
 	      case EditorItemTypeHeader:
@@ -526,7 +518,7 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 		closed_m = pixmaps_list->manpage_section_20x20_mask;
 		opened_p = closed_p;
 		opened_m = closed_m;
-		text[0] = src_item_ptr->section_name;
+		text[0] = src_item->section_name;
 		break;
 	    }
 	}
@@ -547,23 +539,22 @@ static GtkCTreeNode *EditorDNDTrunkListAddIterate(
 	);
 
 	/* Set item data to newly inserted branch */
-	item_ptr = EditorItemDup(src_item_ptr);
-	if(item_ptr != NULL)
+	item = EditorItemDup(src_item);
+	if(item != NULL)
 	{
 	    /* Update values on coppied item pointer to reflect new
-	     * target editor values.
+	     * target editor values
 	     */
-	    item_ptr->editor_ptr = (void *)editor;
-
-	    item_ptr->ctree = ctree;
-	    item_ptr->parent = parent_branch;
-	    item_ptr->this_branch = new_branch;
+	    item->editor = editor;
+	    item->ctree = ctree;
+	    item->parent = parent_branch;
+	    item->this_branch = new_branch;
 	}
 	EditorBranchSetData(
 	    ctree, new_branch,
-	    item_ptr, EditorItemDestroyCB
+	    item, EditorItemDestroyCB
 	);
-	item_ptr = NULL;
+	item = NULL;
 
 	/* Mark new branch's item data as having changes */
 	EditorItemSetToplevelHasChanges(
@@ -653,11 +644,11 @@ static void EditorDNDTrunkListAdd(
 	    return;
 
 	/* Get pointer to core structure on target editor */
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
-	    return;
-	else
+	core_ptr = MEDIT_CORE(editor->core_ptr);
+	if(core_ptr != NULL)
 	    pixmaps_list = &core_ptr->pixmaps_list;
+	else
+	    return;
 
 	/* Clip insert row */
 	if(insert_row < 0)
@@ -751,8 +742,7 @@ static void EditorDNDViewerIndexItemLoad(
 	gint i;
 	GtkCList *clist, *src_clist;
 	GtkCTree *ctree, *src_ctree;
-	viewer_index_item_struct *item_ptr;
-
+	viewer_index_item_struct *item;
 
 	if((editor == NULL) || (src_v == NULL) ||
 	   (branch == NULL) || (total_branches <= 0)
@@ -803,23 +793,24 @@ static void EditorDNDViewerIndexItemLoad(
 		if(branch[i] == NULL)
 		    continue;
 
-		/* Get pointer to source viewer's index ctree index item
-		 * structure.
-		 */
-		item_ptr = gtk_ctree_node_get_row_data(
+		/* Get the source Viewer's Item */
+		item = gtk_ctree_node_get_row_data(
 		    src_ctree, branch[i]
 		);
-		if(item_ptr == NULL)
+		if(item == NULL)
 		    continue;
 
-		switch(item_ptr->type)
+		switch(item->type)
 		{
 		  case ViewerIndexItemTypeManualPage:
 		    EditorFileLoad(
-			editor, item_ptr->file_name_full,
+			editor, item->full_path,
 			insert_node, FALSE
 		    );
 		    break;
+		  case ViewerIndexItemTypeDirectory:
+		  case ViewerIndexItemTypeOtherFile:
+		    break;
 		}
 	    }
 	}
@@ -833,23 +824,22 @@ static void EditorDNDViewerIndexItemLoad(
  *	set the icon which it seems to be doing a good job of.
  */
 void EditorDNDSetIcon(
-	editor_struct *editor, editor_item_struct *item_ptr
+	editor_struct *editor, editor_item_struct *item
 )
 {
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 
-
 	if(editor == NULL)
 	    return;
 
-	core_ptr = (medit_core_struct *)editor->core_ptr;
+	core_ptr = MEDIT_CORE(editor->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
 	pixmaps_list = &core_ptr->pixmaps_list;
 
-	if(item_ptr == NULL)
+	if(item == NULL)
 	{
 	
 	}
@@ -858,7 +848,7 @@ void EditorDNDSetIcon(
 	    GdkPixmap *pixmap = NULL;
 	    GdkBitmap *mask = NULL; 
 
-	    switch(item_ptr->type)
+	    switch(item->type)
 	    {
 	      case EditorItemTypeFile:
 /* Check if opened or closed */
@@ -1092,22 +1082,21 @@ void EditorDNDDataRecievedCB(
 		/* Is source editor valid? */
 		if(src_editor != NULL)
 		{
-		    editor_item_struct *item_ptr;
-
+		    editor_item_struct *item;
 
 		    /* Check what types of branch item data types we
 		     * just got.
 		     */
 		    for(i = 0; i < total_branches; i++)
 		    {
-			item_ptr = EditorBranchGetData(
+			item = EditorBranchGetData(
 			    (GtkCTree *)src_editor->layout_ctree, branch[i]
 			);
-			if(item_ptr == NULL)
+			if(item == NULL)
 			    continue;
 
 			/* Check item type */
-			switch(item_ptr->type)
+			switch(item->type)
 			{
 			  case EditorItemTypeFile:
 			    is_branch_file = TRUE;
@@ -1246,14 +1235,14 @@ the same type to drag and drop.",
 			    /* Make duplicates for each new item */
 			    for(i = 0; i < total_new_items; i++)
 			    {
-				item_ptr = EditorBranchGetData(
+				item = EditorBranchGetData(
 				    (GtkCTree *)src_editor->layout_ctree,
 				    branch[i]
 				);
-				if(item_ptr != NULL)
+				if(item != NULL)
 				{
 				    /* Duplicate item */
-				    new_item[i] = EditorItemDup(item_ptr);
+				    new_item[i] = EditorItemDup(item);
 				}
 			    }
 			}
