@@ -6,7 +6,6 @@
 #define EDITORDND_H
 
 #include <gtk/gtk.h>
-
 #include "editor.h"
 
 
@@ -20,7 +19,7 @@ extern gchar *EditorDNDParseURL(
 );
 
 extern void EditorDNDSetIcon(
-        editor_struct *editor, editor_item_struct *item_ptr
+        editor_struct *editor, editor_item_struct *item
 );
 extern void EditorDNDDataRequestCB(
         GtkWidget *widget, GdkDragContext *dc,
@@ -39,4 +38,5 @@ extern void EditorDNDDataDeleteCB(
         GtkWidget *widget, GdkDragContext *dc, gpointer data
 );
 
+
 #endif	/* EDITORDND_H */
