@@ -27,18 +27,18 @@ static gint EditorFileSaveProgressCB(
 
 static void EditorFileLoadParseTitleHeading(
 	editor_struct *editor, const gchar *line_ptr,
-	editor_item_struct *item_ptr
+	editor_item_struct *item
 );
 static void EditorFileLoadParseHeader(
-	editor_struct *editor, editor_item_struct *item_ptr
+	editor_struct *editor, editor_item_struct *item
 );
 
 static void EditorFileSaveFormatHeader(
-	editor_struct *editor, editor_item_struct *item_ptr,
+	editor_struct *editor, editor_item_struct *item,
 	mp_header_struct *mp_header
 );
 static void EditorFileSaveFormatSection(
-	editor_struct *editor, editor_item_struct *item_ptr,
+	editor_struct *editor, editor_item_struct *item,
 	mp_section_struct *mp_section
 );
 
@@ -58,6 +58,17 @@ gint EditorFileSaveAs(
 );
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
 
 /*
  *	Editor file load progress callback.
@@ -110,12 +121,12 @@ static gint EditorFileSaveProgressCB(
 /*
  *	Parses the line containing the groff title heading tag.
  *
- *	Fetched values will be stored on the item_ptr structure which
+ *	Fetched values will be stored on the item structure which
  *	is assumed to be of type EditorItemTypeHeader.
  */
 static void EditorFileLoadParseTitleHeading(
 	editor_struct *editor, const gchar *line_ptr,
-	editor_item_struct *item_ptr
+	editor_item_struct *item
 )
 {
 	gint line_len, seg_len;
@@ -166,8 +177,8 @@ static void EditorFileLoadParseTitleHeading(
 	    tmp_buf[tmp_buf_len] = '\0';
 	}
 	/* Set new value */
-	g_free(item_ptr->header_name);
-	item_ptr->header_name = tmp_buf;
+	g_free(item->header_name);
+	item->header_name = tmp_buf;
 	/* Seek past current quote if any */
 	if(*line_next == '"')
 	    line_next++;
@@ -210,8 +221,8 @@ static void EditorFileLoadParseTitleHeading(
 	    tmp_buf[tmp_buf_len] = '\0';
 	}
 	/* Set new value */
-	g_free(item_ptr->header_section_number);
-	item_ptr->header_section_number = tmp_buf;
+	g_free(item->header_section_number);
+	item->header_section_number = tmp_buf;
 	/* Seek past current quote if any */
 	if(*line_next == '"')
 	    line_next++;
@@ -254,8 +265,8 @@ static void EditorFileLoadParseTitleHeading(
 	    tmp_buf[tmp_buf_len] = '\0';
 	}
 	/* Set new value */
-	g_free(item_ptr->header_version);
-	item_ptr->header_version = tmp_buf;
+	g_free(item->header_version);
+	item->header_version = tmp_buf;
 	/* Seek past current quote if any */
 	if(*line_next == '"')
 	    line_next++;
@@ -298,8 +309,8 @@ static void EditorFileLoadParseTitleHeading(
 	    tmp_buf[tmp_buf_len] = '\0';
 	}
 	/* Set new value */
-	g_free(item_ptr->header_author);
-	item_ptr->header_author = tmp_buf;
+	g_free(item->header_author);
+	item->header_author = tmp_buf;
 	/* Seek past current quote if any */
 	if(*line_next == '"')
 	    line_next++;
@@ -342,8 +353,8 @@ static void EditorFileLoadParseTitleHeading(
 	    tmp_buf[tmp_buf_len] = '\0';
 	}
 	/* Set new value */
-	g_free(item_ptr->header_catagory);
-	item_ptr->header_catagory = tmp_buf;
+	g_free(item->header_catagory);
+	item->header_catagory = tmp_buf;
 	/* Seek past current quote if any */
 	if(*line_next == '"')
 	    line_next++;
@@ -352,22 +363,22 @@ static void EditorFileLoadParseTitleHeading(
 
 /*
  *	Post processing for loading of header item. Parses each line
- *	on the given item_ptr assumed to be of type EditorItemTypeHeader.
+ *	on the given item assumed to be of type EditorItemTypeHeader.
  */
 static void EditorFileLoadParseHeader(
-	editor_struct *editor, editor_item_struct *item_ptr
+	editor_struct *editor, editor_item_struct *item
 )
 {
 	gchar ***line, *line_ptr;
 	gint i, line_num, *total_lines;
 
 
-	if((editor == NULL) || (item_ptr == NULL))
+	if((editor == NULL) || (item == NULL))
 	    return;
 
 	/* Get pointer to lines array on item data */
-	line = &item_ptr->line;
-	total_lines = &item_ptr->total_lines;
+	line = &item->line;
+	total_lines = &item->total_lines;
 
 	/* Go through each line */
 	for(line_num = 0; line_num < (*total_lines); line_num++)
@@ -391,10 +402,10 @@ static void EditorFileLoadParseHeader(
 
 		/* Parse title heading, this will parse the title heading
 		 * arguments pointed to by line_ptr and updates the
-		 * values on the item_ptr.
+		 * values on the item.
 		 */
 		EditorFileLoadParseTitleHeading(
-		    editor, line_ptr, item_ptr
+		    editor, line_ptr, item
 		);
 
 		/* Remove this line from the lines array */
@@ -425,7 +436,7 @@ static void EditorFileLoadParseHeader(
 		 * regular line with the comment's contents without
 		 * the comment prefix.
 		 */
-		new_line_ptr = g_strdup(line_ptr);
+		new_line_ptr = STRDUP(line_ptr);
 
 		/* Free old line */
 		g_free((*line)[line_num]);
@@ -455,7 +466,7 @@ static void EditorFileLoadParseHeader(
  *	first as comments.
  */
 static void EditorFileSaveFormatHeader(
-	editor_struct *editor, editor_item_struct *item_ptr, 
+	editor_struct *editor, editor_item_struct *item, 
 	mp_header_struct *mp_header
 )
 {
@@ -463,7 +474,7 @@ static void EditorFileSaveFormatHeader(
 	const gchar *line;
 	gchar *new_line;
 
-	if((editor == NULL) || (item_ptr == NULL) || (mp_header == NULL))
+	if((editor == NULL) || (item == NULL) || (mp_header == NULL))
 	    return;
 
 	/* Delete any existing lines on manual page header */
@@ -474,7 +485,7 @@ static void EditorFileSaveFormatHeader(
 	/* Allocate lines pointer array on manual page header structure
 	 * to match all lines on item data
 	 */
-	mp_header->total_lines = item_ptr->total_lines;
+	mp_header->total_lines = item->total_lines;
 	if(mp_header->total_lines > 0)
 	{
 	    mp_header->line = (gchar **)g_malloc0(
@@ -491,14 +502,14 @@ static void EditorFileSaveFormatHeader(
 	 * page header structure. Prefixing a comment prefix to each
 	 * line
 	 */
-	for(i = 0; i < item_ptr->total_lines; i++)
+	for(i = 0; i < item->total_lines; i++)
 	{
-	    line = item_ptr->line[i];
+	    line = item->line[i];
 	    if(line == NULL)
 		continue;
 
 	    /* Create new line with a groff comment prefix */
-	    new_line = g_strdup("");
+	    new_line = STRDUP("");
 	    new_line = strcatalloc(new_line, ".\\\" ");
 	    new_line = strcatalloc(new_line, line);
 
@@ -511,11 +522,11 @@ static void EditorFileSaveFormatHeader(
 	/* Append title heading line to manual page header */
 	new_line = g_strdup_printf(
 	    ".TH \"%s\" \"%s\" \"%s\" \"%s\" \"%s\"",
-	    item_ptr->header_name,
-	    item_ptr->header_section_number,
-	    item_ptr->header_version,
-	    item_ptr->header_author,
-	    item_ptr->header_catagory
+	    item->header_name,
+	    item->header_section_number,
+	    item->header_version,
+	    item->header_author,
+	    item->header_catagory
 	);
 
 	i = mp_header->total_lines;
@@ -544,7 +555,7 @@ static void EditorFileSaveFormatHeader(
  *	Section name will be coppied as well.
  */
 static void EditorFileSaveFormatSection(
-	editor_struct *editor, editor_item_struct *item_ptr,
+	editor_struct *editor, editor_item_struct *item,
 	mp_section_struct *mp_section
 )
 {
@@ -553,7 +564,7 @@ static void EditorFileSaveFormatSection(
 	gint i;
 
 
-	if((editor == NULL) || (item_ptr == NULL) || (mp_section == NULL))
+	if((editor == NULL) || (item == NULL) || (mp_section == NULL))
 	    return;
 
 	/* Delete any existing lines on manual page section structure
@@ -567,7 +578,7 @@ static void EditorFileSaveFormatSection(
 	/* Allocate lines pointer array on manual page section structure
 	 * to match all lines on item data structure
 	 */
-	mp_section->total_lines = item_ptr->total_lines;
+	mp_section->total_lines = item->total_lines;
 	if(mp_section->total_lines > 0)
 	{
 	    mp_section->line = (gchar **)g_malloc0(
@@ -583,25 +594,22 @@ static void EditorFileSaveFormatSection(
 	/* First copy each line on the item data structure to the manual
 	 * page section structure
 	 */
-	for(i = 0; i < item_ptr->total_lines; i++)
+	for(i = 0; i < item->total_lines; i++)
 	{
-	    line_ptr = item_ptr->line[i];
+	    line_ptr = item->line[i];
 	    if(line_ptr == NULL)
 		continue;
 	    
 	    /* Create new line */
-	    new_line_ptr = g_strdup(line_ptr);
+	    new_line_ptr = STRDUP(line_ptr);
 
 	    /* Set new line to manual page section structure line array */
 	    mp_section->line[i] = new_line_ptr;
 	}
 
 	/* Copy section name */
-	if(item_ptr->section_name != NULL)
-	{
-	    g_free(mp_section->section);
-	    mp_section->section = g_strdup(item_ptr->section_name);
-	}
+	g_free(mp_section->section);
+	mp_section->section = STRDUP(item->section_name);
 }
 
 
@@ -619,7 +627,7 @@ static void EditorFileSaveFormatSection(
  *	Existing layout trunks on the editor will not be modified.
  *
  *	If as_template is TRUE then the loaded maual page will not have
- *	its file_name_full set on the main trunk branch and the editor's
+ *	its full_path set on the main trunk branch and the editor's
  *	last opened path will not be modified.
  *
  *	Returns non-zero on error, where -1 is a general error and -2 is
@@ -640,7 +648,7 @@ gint EditorFileLoad(
 	GtkCTree *ctree;
 	GtkCList *clist;
 	GtkCTreeNode *trunk, *new_trunk = NULL;
-	editor_item_struct *editor_item_ptr;
+	editor_item_struct *editor_item;
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 
@@ -778,7 +786,7 @@ gint EditorFileLoad(
 		 * filename as tmp_path and make a copy of it
 		 */
 		cs = strrchr(filename, G_DIR_SEPARATOR);
-		tmp_path = g_strdup((cs != NULL) ? (cs + 1) : filename);
+		tmp_path = STRDUP((cs != NULL) ? (cs + 1) : filename);
 		text[0] = tmp_path;
 
 		/* Create new trunk, insert before trunk which is the
@@ -802,7 +810,7 @@ gint EditorFileLoad(
 		trunk = branch;
 
 		/* Create editor item structure */
-		editor_item_ptr = EditorItemNew(
+		editor_item = EditorItemNew(
 		    EditorItemTypeFile,
 		    editor,
 		    ctree,
@@ -811,7 +819,7 @@ gint EditorFileLoad(
 		    FALSE,		/* Is leaf */
 		    NULL, 0
 		);
-		if(editor_item_ptr != NULL)
+		if(editor_item != NULL)
 		{
 		    /* Loading as template? */
 		    if(as_template)
@@ -820,22 +828,22 @@ gint EditorFileLoad(
 			 * name and increment untitled count on core
 			 */
 			core_ptr->untitled_count++;
-			g_free(editor_item_ptr->file_name);
-			editor_item_ptr->file_name = g_strdup_printf(
+			g_free(editor_item->name);
+			editor_item->name = g_strdup_printf(
 			    "Untitled%i.1",
 			    core_ptr->untitled_count
 			);
 
 			/* Mark as having changes */
-			editor_item_ptr->has_changes = TRUE;
+			editor_item->has_changes = TRUE;
 		    }
 		    else
 		    {
 			/* Loading regularly, so record file name as
 			 * usual
 			 */
-			g_free(editor_item_ptr->file_name);
-			editor_item_ptr->file_name = g_strdup(tmp_path);
+			g_free(editor_item->name);
+			editor_item->name = STRDUP(tmp_path);
 		    }
 
 		    /* Record full file name only if not loading as
@@ -844,13 +852,13 @@ gint EditorFileLoad(
 		     */
 		    if(!as_template)
 		    {
-		        g_free(editor_item_ptr->file_name_full);
-		        editor_item_ptr->file_name_full = g_strdup(filename);
+		        g_free(editor_item->full_path);
+		        editor_item->full_path = STRDUP(filename);
 		    }
 		}
 		EditorBranchSetData(
 		    ctree, branch,
-		    editor_item_ptr, EditorItemDestroyCB
+		    editor_item, EditorItemDestroyCB
 		);
 
 		g_free(tmp_path);
@@ -879,7 +887,7 @@ gint EditorFileLoad(
 		    );
 
 		    /* Create new editor item structure */
-		    editor_item_ptr = EditorItemNew(
+		    editor_item = EditorItemNew(
 		        EditorItemTypeHeader,
 			editor,
 			ctree,
@@ -899,14 +907,14 @@ gint EditorFileLoad(
 		    /* Set branch data as new editor_item_struct */
 		    EditorBranchSetData(
 			ctree, branch,
-			editor_item_ptr, EditorItemDestroyCB
+			editor_item, EditorItemDestroyCB
 		    );
 
 		    /* Do post processing on header item data, need
 		     * to fetch the header item's title heading.
 		     */
 		    EditorFileLoadParseHeader(
-			editor, editor_item_ptr
+			editor, editor_item
 		    );
 		}
 
@@ -957,7 +965,7 @@ gint EditorFileLoad(
 		    );
 
 		    /* Create new editor item structure */  
-		    editor_item_ptr = EditorItemNew(
+		    editor_item = EditorItemNew(
 			EditorItemTypeSection,
 			editor,
 			ctree,
@@ -974,17 +982,16 @@ gint EditorFileLoad(
 		    mp_section_ptr->line = NULL;
 		    mp_section_ptr->total_lines = 0;
 
-		    if(editor_item_ptr != NULL)
+		    if(editor_item != NULL)
 		    {
-			g_free(editor_item_ptr->section_name);
-			editor_item_ptr->section_name = (text[0] != NULL) ?
-			    g_strdup(text[0]) : NULL;
+			g_free(editor_item->section_name);
+			editor_item->section_name = STRDUP(text[0]);
 		    }
 
 		    /* Set branch data as new editor_item_struct */
 		    EditorBranchSetData(
 			ctree, branch,
-			editor_item_ptr, EditorItemDestroyCB
+			editor_item, EditorItemDestroyCB
 		    );
 
 		    g_free(tmp_text);
@@ -1011,7 +1018,7 @@ gint EditorFileLoad(
 	if(!as_template)
 	{
 	    g_free(editor->last_open_path);
-	    editor->last_open_path = g_strdup(filename);
+	    editor->last_open_path = STRDUP(filename);
 	    if(editor->last_open_path != NULL)
 	    {
 		s = strrchr(editor->last_open_path, G_DIR_SEPARATOR);
@@ -1059,7 +1066,7 @@ gint EditorFileLoad(
  *	The given branch pointer may not be NULL, it may either be a child
  *	branch node or a toplevel trunk node. The file to be saved to will
  *	be the one stored on the toplevel trunk branch's item data
- *	file_name_full.
+ *	full_path.
  *
  *	Has changes markers will not be modified in this function, it is
  *	up to the calling function to set that.
@@ -1079,7 +1086,7 @@ gint EditorFileSave(
 	gint total_mp_sections;
 	GtkCTree *ctree;
 	GtkCTreeNode *trunk;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	medit_core_struct *core_ptr;
 
 
@@ -1116,13 +1123,13 @@ gint EditorFileSave(
 	if(trunk != NULL)
 	{
 	    /* Get item pointer on trunk */
-	    item_ptr = EditorBranchGetData(ctree, trunk);
-	    if(item_ptr != NULL)
+	    item = EditorBranchGetData(ctree, trunk);
+	    if(item != NULL)
 	    {
 		/* Skip type check */
 
 		/* Get absolute path of file name */
-		filename = item_ptr->file_name_full;
+		filename = item->full_path;
 	    }
 	}
 	if(filename == NULL)
@@ -1187,11 +1194,11 @@ different path.",
 	{
 	    GtkCTreeRow *node_row;
 
-	    item_ptr = EditorBranchGetData(ctree, branch);
-	    if(item_ptr != NULL)
+	    item = EditorBranchGetData(ctree, branch);
+	    if(item != NULL)
 	    {
 		/* Handle item data by type */
-		switch(item_ptr->type)
+		switch(item->type)
 		{
 		  case EditorItemTypeHeader:
 		    /* Destroy current header if exists */
@@ -1207,7 +1214,7 @@ different path.",
 			 * to the manual page header structure formatted
 			 */
 			EditorFileSaveFormatHeader(
-			    editor, item_ptr, mp_header
+			    editor, item, mp_header
 			);
 		    }
 		    break;
@@ -1245,12 +1252,13 @@ different path.",
 			 * to the manual page section structure formatted.
 			 */
 			EditorFileSaveFormatSection(
-			    editor, item_ptr, mp_section_ptr
+			    editor, item, mp_section_ptr
 			);
 		    }
 		    break;
-	
 
+		  case EditorItemTypeFile:
+		    break;
 		}
 	    }
 
@@ -1319,7 +1327,7 @@ gint EditorFileSaveAs(
 	GtkCTree *ctree;
 	GtkCTreeRow *branch_row;
 	GtkCTreeNode *trunk;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
 	struct stat stat_buf;
@@ -1374,8 +1382,8 @@ gint EditorFileSaveAs(
 	    return(-1);
 
 	/* Get pointer to item data on trunk */
-	item_ptr = EditorBranchGetData(ctree, trunk);
-	if(item_ptr == NULL)
+	item = EditorBranchGetData(ctree, trunk);
+	if(item == NULL)
 	    return(-1);
 
 	/* Check if file exists */
@@ -1417,25 +1425,25 @@ file, if you are unsure say cancel.",
 	/* Got all required data, now update file name on item data */
 
 	/* Update item data's full file name */
-	g_free(item_ptr->file_name_full);
-	item_ptr->file_name_full = g_strdup(filename);
+	g_free(item->full_path);
+	item->full_path = STRDUP(filename);
 
 	/* Update item data's file name */
 	cs = strrchr(filename, G_DIR_SEPARATOR);
 	if(cs == NULL)
 	{
-	    g_free(item_ptr->file_name);
-	    item_ptr->file_name = g_strdup(filename);
+	    g_free(item->name);
+	    item->name = STRDUP(filename);
 	}
 	else
 	{
 	    cs += 1;	/* Seek past deliminator */
 
-	    g_free(item_ptr->file_name);
-	    item_ptr->file_name = g_strdup(cs);
+	    g_free(item->name);
+	    item->name = STRDUP(cs);
 	}
 	/* Update toplevel trunk branch name */
-	if(item_ptr->file_name != NULL)
+	if(item->name != NULL)
 	{
 	    branch_row = GTK_CTREE_ROW(trunk);
 	    if((branch_row == NULL) ? 0 : branch_row->expanded)
@@ -1444,7 +1452,7 @@ file, if you are unsure say cancel.",
 		    ctree,
 		    branch,
 		    0,              /* Column */
-		    item_ptr->file_name,
+		    item->name,
 		    MEDIT_LIST_ICON_TEXT_SPACING,
 		    pixmaps_list->manual_opened_20x20,
 		    pixmaps_list->manual_opened_20x20_mask
@@ -1456,7 +1464,7 @@ file, if you are unsure say cancel.",
 		    ctree,
 		    branch,
 		    0,              /* Column */
-		    item_ptr->file_name,
+		    item->name,
 		    MEDIT_LIST_ICON_TEXT_SPACING,
 		    pixmaps_list->manual_closed_20x20,
 		    pixmaps_list->manual_closed_20x20_mask
@@ -1470,7 +1478,7 @@ file, if you are unsure say cancel.",
 
 	/* Update last opened path */
 	g_free(editor->last_save_as_path);
-	editor->last_save_as_path = g_strdup(filename);
+	editor->last_save_as_path = STRDUP(filename);
 	if(editor->last_save_as_path != NULL)
 	{
 	    s = strrchr(editor->last_save_as_path, G_DIR_SEPARATOR);
