@@ -59,10 +59,16 @@ gint EditorDoReplaceAll(
 );
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -521,12 +527,11 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 {
 	gint i;
 	gint map_editor_panel_type = -1;
+	GtkStyle *style;
 	GtkWidget *w;
-	editor_item_struct *item_data_ptr;
+	editor_item_struct *item;
 	medit_core_struct *core_ptr;
 	medit_styles_list_struct *styles_list;
-	GtkStyle *style_ptr;
-
 
 	if((editor == NULL) || (branch == NULL))
 	    return;
@@ -539,22 +544,20 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    return;
 
 	/* Get core pointer and subsequently the styles list */
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
-	    styles_list = NULL;
-	else
-	    styles_list = &core_ptr->styles_list;
+	core_ptr = MEDIT_CORE(editor->core_ptr);
+	styles_list = (core_ptr != NULL) ?
+	    &core_ptr->styles_list : NULL;
 
 
 	/* Get pointer to item data from ctree branch node */
-	item_data_ptr = EditorBranchGetData(
-	    (GtkCTree *)editor->layout_ctree, branch
+	item = EditorBranchGetData(
+	    GTK_CTREE(editor->layout_ctree), branch
 	);
 
 
 	/* Map and unmap editor panel widgets */
-	if(item_data_ptr != NULL)
-	    map_editor_panel_type = item_data_ptr->type;
+	if(item != NULL)
+	    map_editor_panel_type = item->type;
 
 	for(i = 0; i < MEDIT_EDIT_PANEL_MAX; i++)
 	{
@@ -583,55 +586,55 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    w = editor->header_name_entry;
 	    if(w != NULL)
 	    {
-		if((item_data_ptr == NULL) ?
-		    0 : (item_data_ptr->header_name != NULL)
+		if((item == NULL) ?
+		    0 : (item->header_name != NULL)
 		)
 		    gtk_entry_set_text(
-			GTK_ENTRY(w), item_data_ptr->header_name
+			GTK_ENTRY(w), item->header_name
 		    );
 	    }
 
 	    w = editor->header_section_number_entry;
 	    if(w != NULL)
 	    {
-		if((item_data_ptr == NULL) ?    
-		    0 : (item_data_ptr->header_section_number != NULL)
+		if((item == NULL) ?    
+		    0 : (item->header_section_number != NULL)
 		)
 		    gtk_entry_set_text(
-			GTK_ENTRY(w), item_data_ptr->header_section_number
+			GTK_ENTRY(w), item->header_section_number
 		    );
 	    }     
 
 	    w = editor->header_version_entry;
 	    if(w != NULL)
 	    {
-		if((item_data_ptr == NULL) ?
-		    0 : (item_data_ptr->header_version != NULL)
+		if((item == NULL) ?
+		    0 : (item->header_version != NULL)
 		)
 		    gtk_entry_set_text(
-			GTK_ENTRY(w), item_data_ptr->header_version
+			GTK_ENTRY(w), item->header_version
 		    );
 	    }
 
 	    w = editor->header_author_entry;
 	    if(w != NULL)
 	    {
-		if((item_data_ptr == NULL) ?
-		    0 : (item_data_ptr->header_author != NULL)
+		if((item == NULL) ?
+		    0 : (item->header_author != NULL)
 		)
 		    gtk_entry_set_text(
-			GTK_ENTRY(w), item_data_ptr->header_author
+			GTK_ENTRY(w), item->header_author
 		    );
 	    }
 
 	    w = editor->header_catagory_entry;
 	    if(w != NULL)
 	    {
-		if((item_data_ptr == NULL) ?
-		    0 : (item_data_ptr->header_catagory != NULL)
+		if((item == NULL) ?
+		    0 : (item->header_catagory != NULL)
 		)
 		    gtk_entry_set_text(
-			GTK_ENTRY(w), item_data_ptr->header_catagory
+			GTK_ENTRY(w), item->header_catagory
 		    );
 	    }
 
@@ -649,28 +652,28 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		gtk_text_thaw(GTK_TEXT(w));
 
 		/* Item data valid? */
-		if(item_data_ptr != NULL)
+		if(item != NULL)
 		{
 		    gchar *line_ptr;
 
 
 		    if(styles_list != NULL)
-			style_ptr = styles_list->edit_text_standard;
+			style = styles_list->edit_text_standard;
 		    else
-			style_ptr = NULL;
+			style = NULL;
 
 		    /* Set lines from item to text widget */
 		    gtk_text_freeze(GTK_TEXT(w));
-		    for(i = 0; i < item_data_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 		    {
-			line_ptr = item_data_ptr->line[i];
+			line_ptr = item->line[i];
 			if(line_ptr == NULL)
 			    continue;
 
 			/* Insert this line */
 			gtk_text_insert(
 			    GTK_TEXT(w),
-			    (style_ptr != NULL) ? style_ptr->font : NULL,
+			    (style != NULL) ? style->font : NULL,
 			    NULL,	/* Foreground color */
 			    NULL,	/* Background color */
 			    line_ptr,
@@ -680,7 +683,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 			/* Need to insert a newline character at end */
 			gtk_text_insert(
 			    GTK_TEXT(w),
-			    (style_ptr != NULL) ? style_ptr->font : NULL,
+			    (style != NULL) ? style->font : NULL,
 			    NULL,       /* Foreground color */
 			    NULL,       /* Background color */
 			    "\n",
@@ -699,8 +702,8 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 	    {
 		gtk_entry_set_text(
 		    GTK_ENTRY(w),
-		    (item_data_ptr == NULL) ?
-			"" : item_data_ptr->section_name
+		    (item == NULL) ?
+			"" : item->section_name
 		);
 	    }
 
@@ -718,28 +721,28 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 		gtk_text_thaw(GTK_TEXT(w));
 
 		/* Item data valid? */  
-		if(item_data_ptr != NULL)
+		if(item != NULL)
 		{
 		    gchar *line_ptr;
 
 
 		    if(styles_list != NULL)
-			style_ptr = styles_list->edit_text_standard;
+			style = styles_list->edit_text_standard;
 		    else  
-			style_ptr = NULL;
+			style = NULL;
 
 		    /* Set lines from item to text widget */
 		    gtk_text_freeze(GTK_TEXT(w));
-		    for(i = 0; i < item_data_ptr->total_lines; i++)
+		    for(i = 0; i < item->total_lines; i++)
 		    {
-			line_ptr = item_data_ptr->line[i];
+			line_ptr = item->line[i];
 			if(line_ptr == NULL)
 			    continue;
 
 			/* Insert this line */
 			gtk_text_insert(
 			    GTK_TEXT(w),
-			    (style_ptr != NULL) ? style_ptr->font : NULL,
+			    (style != NULL) ? style->font : NULL,
 			    NULL,       /* Foreground color */
 			    NULL,       /* Background color */
 			    line_ptr,
@@ -749,7 +752,7 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 			/* Need to insert a newline character at end */
 			gtk_text_insert( 
 			    GTK_TEXT(w),
-			    (style_ptr != NULL) ? style_ptr->font : NULL,
+			    (style != NULL) ? style->font : NULL,
 			    NULL,       /* Foreground color */
 			    NULL,       /* Background color */
 			    "\n",
@@ -780,11 +783,9 @@ void EditorDoFetchValues(editor_struct *editor, GtkCTreeNode *branch)
 void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 {
 	GtkWidget *w;
-	gchar *strptr;
+	editor_item_struct *item;
 	medit_pixmaps_list_struct *pixmaps_list;
 	medit_core_struct *core_ptr;
-	editor_item_struct *item_data_ptr;
-
 
 	if((editor == NULL) || (branch == NULL))
 	    return;
@@ -796,7 +797,7 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	if(editor->processing)   
 	    return;
 
-	core_ptr = (medit_core_struct *)editor->core_ptr;
+	core_ptr = MEDIT_CORE(editor->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -804,17 +805,17 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 
 
 	/* Get pointer to item data from ctree branch node */
-	item_data_ptr = EditorBranchGetData(
-	    (GtkCTree *)editor->layout_ctree, branch
+	item = EditorBranchGetData(
+	    GTK_CTREE(editor->layout_ctree), branch
 	);
-	if(item_data_ptr == NULL)
+	if(item == NULL)
 	{
 	    /* No data to apply */
 	    return;
 	}
 
 	/* Check ctree branch node data type */
-	switch(item_data_ptr->type)
+	switch(item->type)
 	{
 	  case EditorItemTypeFile:
 
@@ -823,136 +824,96 @@ void EditorDoApplyValues(editor_struct *editor, GtkCTreeNode *branch)
 	  case EditorItemTypeHeader:
 	    /* Header name entry */
 	    w = editor->header_name_entry;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->header_name);
-		    item_data_ptr->header_name = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		} 
+		g_free(item->header_name);
+		item->header_name = STRDUP(gtk_entry_get_text(GTK_ENTRY(w)));
 	    }
-
 	    /* Header section number entry */
 	    w = editor->header_section_number_entry;  
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->header_section_number);
-		    item_data_ptr->header_section_number = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		}
+		g_free(item->header_section_number);
+		item->header_section_number = STRDUP(gtk_entry_get_text(GTK_ENTRY(w)));
 	    }
-
 	    /* Header version entry */
 	    w = editor->header_version_entry;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->header_version);
-		    item_data_ptr->header_version = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		}
+		g_free(item->header_version);
+		item->header_version = STRDUP(gtk_entry_get_text(GTK_ENTRY(w)));
 	    }
-
 	    /* Header author entry */
 	    w = editor->header_author_entry;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->header_author);
-		    item_data_ptr->header_author = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		}
+		g_free(item->header_author);
+		item->header_author = STRDUP(gtk_entry_get_text(GTK_ENTRY(w)));
 	    }
-
 	    /* Header catagory entry */
 	    w = editor->header_catagory_entry;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->header_catagory); 
-		    item_data_ptr->header_catagory = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		}
+		g_free(item->header_catagory); 
+		item->header_catagory = STRDUP(gtk_entry_get_text(GTK_ENTRY(w)));
 	    }
-
 	    /* Header text */
 	    w = editor->header_text;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		gchar *text_buf;
+		gchar *s;
 
-		/* Unload existing lines */
-		strlistfree(item_data_ptr->line, item_data_ptr->total_lines);
-		item_data_ptr->line = NULL;
-		item_data_ptr->total_lines = 0;
+		/* Delete existing lines */
+		strlistfree(item->line, item->total_lines);
+		item->line = NULL;
+		item->total_lines = 0;
 
-		/* Load new lines from widget */
-		text_buf = gtk_editable_get_chars(
+		/* Get new lines */
+		s = gtk_editable_get_chars(
 		    GTK_EDITABLE(w), 0, -1
 		);
-		item_data_ptr->line = strchrexp(
-		    text_buf, '\n', &item_data_ptr->total_lines
-		);
-		g_free(text_buf);
+		item->line = strchrexp(s, '\n', &item->total_lines);
+		g_free(s);
 	    }
 	    break;
 
 	  case EditorItemTypeSection:
 	    /* Section name entry */
 	    w = editor->section_name_entry;
-	    if(w != NULL)
+	    if((w != NULL) && (item != NULL))
 	    {
-		strptr = gtk_entry_get_text(GTK_ENTRY(w));
-		if(item_data_ptr != NULL)
-		{
-		    g_free(item_data_ptr->section_name);
-		    item_data_ptr->section_name = (strptr != NULL) ?
-			g_strdup(strptr) : NULL;
-		}
-		if(strptr != NULL)
-		{
+		gchar *s = gtk_entry_get_text(GTK_ENTRY(w));
+
+		g_free(item->section_name);
+		item->section_name = STRDUP(s);
+
+		if(s != NULL)
 		    gtk_ctree_node_set_pixtext(
-			(GtkCTree *)editor->layout_ctree,
+			GTK_CTREE(editor->layout_ctree),
 			branch,		/* Branch node */
 			0,		/* Column */
-			strptr,
+			s,
 			MEDIT_LIST_ICON_TEXT_SPACING,
 			pixmaps_list->manpage_section_20x20,
 			pixmaps_list->manpage_section_20x20_mask
 		    );
-		}
 	    }
 
 	    /* Section text */
 	    w = editor->section_text;
 	    if(w != NULL)
 	    {
-		gchar *text_buf;
+		gchar *s;
 
-		/* Unload existing lines */
-		strlistfree(item_data_ptr->line, item_data_ptr->total_lines);
-		item_data_ptr->line = NULL;
-		item_data_ptr->total_lines = 0;
+		/* Delete existing lines */
+		strlistfree(item->line, item->total_lines);
+		item->line = NULL;
+		item->total_lines = 0;
 
-		/* Load new lines from widget */
-		text_buf = gtk_editable_get_chars(
-		    GTK_EDITABLE(w), 0, -1
-		);
-		item_data_ptr->line = strchrexp(
-		    text_buf, '\n', &item_data_ptr->total_lines
-		);
-		g_free(text_buf);
+		/* Get new lines */
+		s = gtk_editable_get_chars(GTK_EDITABLE(w), 0, -1);
+		item->line = strchrexp(s, '\n', &item->total_lines);
+		g_free(s);
 	    }
 	    break;
 	}
@@ -1051,9 +1012,9 @@ void EditorDoPreview(
 	viewer_struct *v;
 	medit_core_struct *core_ptr;
 	GtkCTreeNode *trunk;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	GtkCTree *ctree;
-	gchar *orig_file_name_full, *tmp_path, *prog_tmp_path;
+	gchar *orig_path, *tmp_path, *prog_tmp_path;
 
 
 	if(editor == NULL)
@@ -1087,11 +1048,8 @@ void EditorDoPreview(
 	    editor_num = -1;
 
 	/* Check if viewer_num is valid on the core structure */
-	if((viewer_num < 0) || (viewer_num >= core_ptr->total_viewers))
-	    v = NULL;
-	else
-	    v = core_ptr->viewer[viewer_num];
-
+	v = ((viewer_num >= 0) && (viewer_num < core_ptr->total_viewers)) ?
+	    core_ptr->viewer[viewer_num] : NULL;
 	if(v == NULL)
 	{
 	    gchar *s = g_strdup_printf(
@@ -1138,8 +1096,8 @@ Cannot continue with preview.",
 	}
 
 	/* Get trunk item pointer */
-	item_ptr = EditorBranchGetData(ctree, trunk);
-	if(item_ptr == NULL)
+	item = EditorBranchGetData(ctree, trunk);
+	if(item == NULL)
 	{
 	    CDialogGetResponse(
 "Non-critical internal error!",
@@ -1187,8 +1145,8 @@ Cannot continue with preview.",
 	 * so that it gets saved to that. After saving we set back
 	 * the file path name on the item data to what it was
 	 */
-	orig_file_name_full = item_ptr->file_name_full;
-	item_ptr->file_name_full = tmp_path;
+	orig_path = item->full_path;
+	item->full_path = tmp_path;
 	tmp_path = NULL;
 
 	/* Save branch with an updated filename to the tempory file */
@@ -1199,20 +1157,20 @@ Cannot continue with preview.",
 	ViewerTextDelete(v, 0, -1);
 	ViewerTextInsertPosition(v, 0);
 	status = ViewerLoadFile(
-	    v, item_ptr->file_name_full, orig_file_name_full
+	    v, item->full_path, orig_path
 	);
 
 	/* Remove tempory saved manual page */
-	if(item_ptr->file_name_full != NULL)
-	    unlink(item_ptr->file_name_full);
+	if(item->full_path != NULL)
+	    unlink(item->full_path);
 
 
 	/* Free tempory path (this was our tmp_path) */
-	g_free(item_ptr->file_name_full);
+	g_free(item->full_path);
 
 	/* Set back original full file name on item */
-	item_ptr->file_name_full = orig_file_name_full;
-	orig_file_name_full = NULL;
+	item->full_path = orig_path;
+	orig_path = NULL;
 
 
 	/* Free program tempory files directory path */
