@@ -1,10 +1,4 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <stdlib.h>
-
 #include <gtk/gtk.h>
-#include <sys/types.h>
 
 #include "../include/string.h"
 
@@ -15,10 +9,11 @@
 #include "manedit.h"
 
 
-void *EditorUndoNew(
-	editor_struct *editor, int type, const char *comment
+gpointer EditorUndoNew(
+	editor_struct *editor, editor_undo_type type,
+	const gchar *comment
 );
-void EditorUndoDelete(editor_struct *editor, void *u);
+void EditorUndoDelete(editor_struct *editor, gpointer u);
 
 static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
 	editor_undo_remove_chars_struct *u_remove
@@ -27,11 +22,11 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	editor_undo_insert_chars_struct *u_insert
 );
 
-int EditorUndoDoApply(
+gint EditorUndoDoApply(
 	editor_struct *editor,
-	void ***in_list, int *in_total,
-	void ***out_list, int *out_total,
-	int max
+	gpointer **in_list, gint *in_total,
+	gpointer **out_list, gint *out_total,
+	gint max
 );
 
 
@@ -44,12 +39,13 @@ int EditorUndoDoApply(
  *	Allocates a new undo structure with the given type and initial
  *	values.
  */
-void *EditorUndoNew(
-	editor_struct *editor, int type, const char *comment
+gpointer EditorUndoNew(
+	editor_struct *editor, editor_undo_type type,
+	const gchar *comment
 )
 {
-	int len = 0;
-	void *u = NULL;
+	gint len = 0;
+	gpointer u = NULL;
 
 	switch(type)
 	{
@@ -64,17 +60,16 @@ void *EditorUndoNew(
 
 	if(len > 0)
 	{
-	    u = calloc(1, len);
+	    u = g_malloc0(len);
 	    if(u != NULL)
 	    {
-		editor_undo_common_struct *common = (editor_undo_common_struct *)u;
+		editor_undo_common_struct *common = EDITOR_UNDO_COMMON(u);
 
-		/* Set common member values. */
+		/* Set common member values */
 		common->type = type;
-		common->comment = ((comment != NULL) ?
-		    strdup(comment) : NULL
-		);
-		common->editor_ptr = (void *)editor;
+		common->comment = (comment != NULL) ?
+		    g_strdup(comment) : NULL;
+		common->editor_ptr = editor;
 	    }
 	}
 
@@ -82,31 +77,35 @@ void *EditorUndoNew(
 }
 
 /*
- *	Deallocates the undo structure and all its allocated resources.
+ *	Deletes the undo structure and all its allocated resources.
  */
-void EditorUndoDelete(editor_struct *editor, void *u)
+void EditorUndoDelete(editor_struct *editor, gpointer u)
 {
+	editor_undo_remove_chars_struct *u_remove;
 	editor_undo_insert_chars_struct *u_insert;
- 	editor_undo_common_struct *common = (editor_undo_common_struct *)u;
-	if(common == NULL)
+ 	editor_undo_common_struct *u_common;
+
+	if(u == NULL)
 	    return;
 
-	/* Free type specific data. */
-	switch(common->type)
+	/* Delete type specific data */
+	switch(EDITOR_UNDO_COMMON(u)->type)
 	{
+	  case EDITOR_UNDO_REMOVE_CHARS:
+	    u_remove = EDITOR_UNDO_REMOVE_CHARS(u);
+	    break;
+
 	  case EDITOR_UNDO_INSERT_CHARS:
-	    u_insert = (editor_undo_insert_chars_struct *)common;
-	    free(u_insert->characters);
+	    u_insert = EDITOR_UNDO_INSERT_CHARS(u);
+	    g_free(u_insert->characters);
 	    break;
 	}
 
-	/* Free common members. */
-	free(common->comment);
+	/* Delete common members */
+	u_common = EDITOR_UNDO_COMMON(u);
+	g_free(u_common->comment);
 
-	/* Free structure itself. */
-	free(common);
-
-	return;
+	g_free(u);
 }
 
 
@@ -116,8 +115,8 @@ void EditorUndoDelete(editor_struct *editor, void *u)
  *
  *	Returns an inverse insert characters operation or NULL on error.
  *
- *	Given input undo structure will be deallocated and should not be
- * 	referanced again after this call.
+ *	Given input undo structure will be deleted and should not be
+ * 	referenced again after this call.
  */
 static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
 	editor_undo_remove_chars_struct *u_remove
@@ -133,13 +132,13 @@ static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
 	if(u_remove == NULL)
 	    return(u_insert);
 
-	editor = (editor_struct *)u_remove->editor_ptr;
+	editor = EDITOR(u_remove->editor_ptr);
 	editable = (GtkEditable *)u_remove->w;
 	text = (GtkText *)u_remove->w;
 	if((editor == NULL) || (editable == NULL))
 	    return(u_insert);
 
-	/* Get characters from editable that we're about to remove. */
+	/* Get characters from editable that we're about to remove */
 	if(u_remove->length > 0)
 	    text_buf = gtk_editable_get_chars(
 		editable,
@@ -147,29 +146,27 @@ static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
 		u_remove->position + u_remove->length
 	    );
 
-	/* Create inverse operation structure and set values. */
-	u_insert = (editor_undo_insert_chars_struct *)EditorUndoNew(
+	/* Create inverse operation structure and set values */
+	u_insert = EDITOR_UNDO_INSERT_CHARS(EditorUndoNew(
 	    editor, EDITOR_UNDO_INSERT_CHARS,
 	    u_remove->comment
-	);
+	));
 	if(u_insert != NULL)
 	{
 	    u_insert->w = GTK_WIDGET(editable);
 
 	    u_insert->position = u_remove->position;
-	    u_insert->length = ((text_buf != NULL) ?
-		u_remove->length : 0
-	    );
+	    u_insert->length = (text_buf != NULL) ?
+		u_remove->length : 0;
 
-	    free(u_insert->characters);
-	    u_insert->characters = ((text_buf != NULL) ?
-		strdup(text_buf) : NULL
-	    );
+	    g_free(u_insert->characters);
+	    u_insert->characters = (text_buf != NULL) ?
+		g_strdup(text_buf) : NULL;
 	}
 	g_free(text_buf);
 	text_buf = NULL;
 
-	/* Now remove the characters. */
+	/* Now remove the characters */
 	if(use_text_delete)
 	{
 	    gtk_text_freeze(text);
@@ -188,7 +185,7 @@ static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
 	    gtk_text_thaw(text);
 	}
 
-	/* Deallocate the input structure. */
+	/* Delete the input structure */
 	EditorUndoDelete(editor, u_remove);
 	u_remove = NULL;
 
@@ -200,8 +197,8 @@ static editor_undo_insert_chars_struct *EditorUndoApplyRemove(
  *
  *      Returns an inverse remove characters operation or NULL on error.
  * 
- *      Given input undo structure will be deallocated and should not be
- *      referanced again after this call.
+ *      Given input undo structure will be deleted and should not be
+ *      referenced again after this call.
  */
 static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	editor_undo_insert_chars_struct *u_insert
@@ -215,15 +212,15 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	if(u_insert == NULL)
 	    return(u_remove);
 
-	editor = (editor_struct *)u_insert->editor_ptr;
+	editor = EDITOR(u_insert->editor_ptr);
 	editable = (GtkEditable *)u_insert->w;
 	if((editor == NULL) || (editable == NULL))
 	    return(u_remove);
 
-	/* Insert characters. */
+	/* Insert characters */
 	if((u_insert->length > 0) && (u_insert->characters != NULL))
 	{
-	    medit_core_struct *core_ptr = (medit_core_struct *)editor->core_ptr;
+	    medit_core_struct *core_ptr = MEDIT_CORE(editor->core_ptr);
 	    medit_styles_list_struct *styles_list = NULL;
 	    GtkStyle *style_ptr = NULL;
 
@@ -240,8 +237,8 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	    gtk_text_insert(
 		GTK_TEXT(editable),
 		(style_ptr != NULL) ? style_ptr->font : NULL,
-		NULL,		/* Foreground color. */
-		NULL,		/* Background color. */
+		NULL,		/* Foreground color */
+		NULL,		/* Background color */
 		u_insert->characters,
 		u_insert->length
 	    );
@@ -266,11 +263,11 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	    );
 	}
 
-	/* Create inverse operation structure and set values. */
-	u_remove = (editor_undo_remove_chars_struct *)EditorUndoNew(
+	/* Create inverse operation structure and set values */
+	u_remove = EDITOR_UNDO_REMOVE_CHARS(EditorUndoNew(
 	    editor, EDITOR_UNDO_REMOVE_CHARS,
 	    u_insert->comment
-	);
+	));
 	if(u_remove != NULL)
 	{
 	    u_remove->w = GTK_WIDGET(editable);
@@ -279,7 +276,7 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
 	    u_remove->length = u_insert->length;
 	}
 
-	/* Deallocate the input structure. */
+	/* Delete the input structure */
 	EditorUndoDelete(editor, u_insert);
 	u_insert = NULL;
 
@@ -297,131 +294,135 @@ static editor_undo_remove_chars_struct *EditorUndoApplyInsert(
  *
  *	Returns non-zero on error.
  */
-int EditorUndoDoApply(
+gint EditorUndoDoApply(
 	editor_struct *editor,
-	void ***in_list, int *in_total,
-	void ***out_list, int *out_total,
-	int max
+	gpointer **in_list, gint *in_total,
+	gpointer **out_list, gint *out_total,
+	gint max
 )
 {
-	int i, n;
-	void *u_in;
-	void *u_inverse = NULL;
+	gint i, n;
+	gpointer u_in, u_inverse = NULL;
 
 
 	if((editor == NULL) || (in_list == NULL) || (in_total == NULL))
 	    return(-1);
 
 	/* Nothing to do? */
-	if(((*in_list) == NULL) || ((*in_total) < 1))
+	if((*in_list == NULL) || (*in_total < 1))
 	    return(0);
 
 
 	/* Get first undo operation from input list, newest undo
-	 * operation is always the first in the list.
+	 * operation is always the first in the list
 	 */
 	u_in = (*in_list)[0];
 
-	/* Reduce and shift input list. */
-	(*in_total) = (*in_total) - 1;
-	for(i = 0; i < (*in_total); i++)
+	/* Reduce and shift input list */
+	*in_total = (*in_total) - 1;
+	for(i = 0; i < *in_total; i++)
 	    (*in_list)[i] = (*in_list)[i + 1];
 
-	if((*in_total) > 0)
+	if(*in_total > 0)
 	{
-	    (*in_list) = (void **)realloc(
-		*in_list, (*in_total) * sizeof(void *)
+	    *in_list = (gpointer *)g_realloc(
+		*in_list, (*in_total) * sizeof(gpointer)
 	    );
-	    if((*in_list) == NULL)
-		(*in_total) = 0;
+	    if(*in_list == NULL)
+		*in_total = 0;
 	}
 	else
 	{
-	    free(*in_list);
-	    (*in_list) = NULL;
-	    (*in_total) = 0;
+	    g_free(*in_list);
+	    *in_list = NULL;
+	    *in_total = 0;
 	}
 
 
 
 	/* Handle input undo operation by its type, note that the
-	 * given input undo structure will be deallocated.
+	 * given input undo structure will be deleted
 	 */
-	switch(*(int *)u_in)
+	switch(EDITOR_UNDO_COMMON(u_in)->type)
 	{
 	  case EDITOR_UNDO_REMOVE_CHARS:
 	    u_inverse = EditorUndoApplyRemove(
-		(editor_undo_remove_chars_struct *)u_in
+		EDITOR_UNDO_REMOVE_CHARS(u_in)
 	    );
+	    u_in = NULL;
 	    break;
 
 	  case EDITOR_UNDO_INSERT_CHARS:
 	    u_inverse = EditorUndoApplyInsert(
-		(editor_undo_insert_chars_struct *)u_in
+		EDITOR_UNDO_INSERT_CHARS(u_in)
 	    );
-	    break;
-
-	  default:
-	    EditorUndoDelete(editor, u_in);
+	    u_in = NULL;
 	    break;
 	}
-	u_in = NULL;
+
+	/* Undo not processed? */
+	if(u_in != NULL)
+	{
+	    EditorUndoDelete(editor, u_in);
+	    u_in = NULL;
+	}
+
 
 
 	/* Did we get an inverse operation? */
 	if(u_inverse != NULL)
 	{
-	    /* Add it to the out list. */
+	    /* Add it to the out list */
 	    if((out_list != NULL) && (out_total != NULL))
 	    {
-		if((*out_total) < 0)
-		   (*out_total) = 0;
+		if(*out_total < 0)
+		   *out_total = 0;
 
-		(*out_total) = (*out_total) + 1;
-		(*out_list) = (void **)realloc(
+		*out_total = (*out_total) + 1;
+		*out_list = (gpointer *)g_realloc(
 		    *out_list,
-		    (*out_total) * sizeof(void *)
+		    (*out_total) * sizeof(gpointer)
 		);
-		if((*out_list) == NULL)
+		if(*out_list == NULL)
 		{
-		    (*out_total) = 0;
+		    *out_total = 0;
 
 		    EditorUndoDelete(editor, u_inverse);
 		    u_inverse = NULL;
 		}
 		else
 		{
-		    /* Shift. */
+		    /* Shift */
 		    for(i = (*out_total) - 1; i > 0; i--)
 			(*out_list)[i] = (*out_list)[i - 1];
 
-		    /* Record newest undo inverse structure as first item. */
+		    /* Record newest undo inverse structure as first item */
 		    (*out_list)[0] = u_inverse;
 		    u_inverse = NULL;
 		}
 
-		/* Delete older undo structures on the out list. */
-		if((*out_total) > max)
+		/* Delete older undo structures on the out list */
+		if(*out_total > max)
 		{
 		    n = MAX(max, 0);
 
-		    /* Delete all undo structures greater than the max. */
+		    /* Delete all undo structures greater than the max */
 		    for(i = (*out_total) - 1; i >= n; i--)
 			EditorUndoDelete(editor, (*out_list)[i]);
 
 		    (*out_total) = n;
 		    if((*out_total) > 0)
 		    {
-			(*out_list) = (void **)realloc(
+			(*out_list) = (gpointer*)g_realloc(
 			    *out_list,
-			    (*out_total) * sizeof(void *)
+			    (*out_total) * sizeof(gpointer)
 			);
 			if((*out_list) == NULL)
 			    (*out_total) = 0;
 		    }
 		    else
 		    {
-			free(*out_list);
+			g_free(*out_list);
 			(*out_list) = NULL;
 			(*out_total) = 0;
 		    }
@@ -429,7 +430,7 @@ int EditorUndoDoApply(
 	    }
 	    else
 	    {
-		/* No out list available, deallocate inverse operation
+		/* No out list available, delete inverse operation
 		 * structure.
 		 */
 		EditorUndoDelete(editor, u_inverse);
