@@ -1,7 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
-#include <ctype.h>
 #include <string.h>
+#include <ctype.h>
 #include <limits.h>
 
 #include "../include/xsw_ctype.h"
@@ -87,10 +87,10 @@ FILE *FOpen(const char *path, const char *mode)
 	{
 	    *strptr2 = *strptr1;
 
-#ifdef __MSW__
+#ifdef _WIN32
 	    if(*strptr2 == '/')
 		*strptr2 = '\\';
-#endif	/* __MSW__ */
+#endif
 
 	    strptr1++; strptr2++;
 	}
@@ -183,28 +183,26 @@ void FSeekPastChar(FILE *fp, char c)
 }
 
 /*
- *	Positions the file pointer fp at the beginning of the value
- *	(skipping any blank characters) after a parameter that matches
- *	the given parameter parm.
+ *	Seeks fp to the beginning of the value of the specified
+ *	parameter.
  *
  *	The delim specifies the deliminator character between the
- *	parameter and the value. The delim can be '\0' to mean `any blanks'
- *	(in case there is no deliminator between parameter and value).
+ *	parameter and the value. The delim can be '\0' to specify
+ *	"any blanks" (in the case of no deliminators between the
+ *	parameter and the value).
  *
  *	Parameters are assumed to not contain spaces or escape sequences.
  *
- *	Returns 0 on successful match and positioning or non-zero on
- *	failure.
+ *	Returns 0 on successful match or non-zero on error.
  */
 int FSeekToParm(FILE *fp, const char *parm, char comment, char delim)
 {
 	int c, parm_len;
 
-
-	if((fp == NULL) || (parm == NULL))
+	if(fp == NULL)
 	    return(-1);
 
-	parm_len = strlen(parm);
+	parm_len = STRLEN(parm);
 	if(parm_len <= 0)
 	    return(-1);
 
