@@ -666,12 +666,19 @@ void FPromptBreakQuery(void)
  */
 void FPromptSetPosition(gint x, gint y)
 {
+	GtkWidget *toplevel, *shadow;
 	FPromptData *p = fprompt;
-	GtkWidget *w = (p != NULL) ? p->toplevel : NULL;
-	if(w == NULL)
+	if(p == NULL)
 	    return;
 
-	gtk_widget_set_uposition(w, x, y);
+	toplevel = p->toplevel;
+	shadow = p->shadow;
+
+	gtk_widget_set_uposition(toplevel, x, y);
+	gdk_window_move(toplevel->window, x, y);
+	gtk_widget_set_uposition(shadow, x, y);
+	gdk_window_move(shadow->window, x, y);
+
 	p->x = x;
 	p->y = y;
 }
@@ -709,11 +716,14 @@ gint FPromptMapQuery(
 	void (*cancel_cb)(gpointer)
 )
 {
-	GtkWidget *w;
+	GtkWidget *w, *toplevel, *shadow;
 	FPromptData *p = fprompt;
 	if(p == NULL)
 	    return(-1);
 
+	toplevel = p->toplevel;
+	shadow = p->shadow;
+
 	/* Set new label */
 	w = p->label;
 	if(w != NULL)
@@ -751,6 +761,7 @@ gint FPromptMapQuery(
 	}
 
 	/* Show/hide buttons */
+	/* Browse */
 	w = p->browse_btn;
 	if(w != NULL)
 	{
@@ -759,7 +770,7 @@ gint FPromptMapQuery(
 	    else
 		gtk_widget_hide(w);	    
 	}
-
+	/* OK */
 	w = p->ok_btn;
 	if(w != NULL)
 	{
@@ -768,7 +779,7 @@ gint FPromptMapQuery(
 	    else
 		gtk_widget_hide(w);
 	}
-
+	/* Cancel */
 	w = p->cancel_btn;
 	if(w != NULL)
 	{
@@ -779,20 +790,28 @@ gint FPromptMapQuery(
 	}
 
 
-	/* Update toplevel */
-	w = p->toplevel;
-	if(w != NULL)
+	/* Update toplevel & shadow */
+	if((toplevel != NULL) && (shadow != NULL))
 	{
-	    gint x = 0, y = 0;
-	    GdkWindow	*window = w->window,
-			*root = (window != NULL) ?
-			    gdk_window_get_parent(window) : NULL;
+	    gint x = 0, y = 0, lwidth, lheight;
+	    GdkWindow	*window,
+			*root = (toplevel->window != NULL) ?
+		gdk_window_get_parent(toplevel->window) : NULL;
 
-	    /* Set size of toplevel */
+	    /* Resize of toplevel & shadow */
 	    p->width = (width > 0) ? width : FPROMPT_DEF_WIDTH;
 	    p->height = (height > 0) ? height : FPROMPT_DEF_HEIGHT;
-	    gtk_widget_set_usize(w, width, height);
-/*	    gtk_widget_queue_resize(w); */
+
+	    gtk_widget_set_usize(toplevel, width, height);
+	    gdk_window_get_size(toplevel->window, &lwidth, &lheight);
+	    gdk_window_resize(
+		toplevel->window,
+		(width > 0) ? width : lwidth,
+		(height > 0) ? height : lheight
+	    );
+
+	    gtk_widget_set_usize(shadow, width, height);
+	    gdk_window_resize(shadow->window, 5, 5);
 
 	    /* Move the toplevel's GdkWindow, calculate x and y
 	     * position relative to parent (root) GdkWindow by the
@@ -809,7 +828,10 @@ gint FPromptMapQuery(
 		    gdk_window_get_size(window, &wwidth, &wheight);
 		    x += (wwidth / 2) - (p->width / 2);
 		    y += (wheight / 2) - (p->height / 2);
-		    gtk_widget_set_uposition(w, x, y);
+		    gtk_widget_set_uposition(toplevel, x, y);
+		    gdk_window_move(toplevel->window, x, y);
+		    gtk_widget_set_uposition(shadow, x, y);
+		    gdk_window_move(shadow->window, x, y);
 		}
 		break;
 
@@ -820,7 +842,10 @@ gint FPromptMapQuery(
 		    x -= (p->width / 2);
 		    y -= (p->height / 2);
 		}
-		gtk_widget_set_uposition(w, x, y);
+		gtk_widget_set_uposition(toplevel, x, y);   
+		gdk_window_move(toplevel->window, x, y);
+		gtk_widget_set_uposition(shadow, x, y);   
+		gdk_window_move(shadow->window, x, y);
 		break;
 
 	      case FPROMPT_MAP_NO_MOVE:
@@ -835,7 +860,7 @@ gint FPromptMapQuery(
 		GdkPixmap *pixmap = GDK_PIXMAP_NEW(p->width, p->height);
 		GtkStyle *style = gtk_widget_get_style(w);
 
-		GDK_PIXMAP_UNREF(p->shadow_pm)
+		GDK_PIXMAP_UNREF(p->shadow_pm);
 		p->shadow_pm = pixmap;
 
 		if(pixmap != NULL)
@@ -994,7 +1019,7 @@ void FPromptUnmap(void)
 	gtk_widget_hide(p->toplevel);
 	gtk_widget_hide(p->shadow);
 
-	GDK_PIXMAP_UNREF(p->shadow_pm)
+	GDK_PIXMAP_UNREF(p->shadow_pm);
 	p->shadow_pm = NULL;
 }
 
@@ -1007,16 +1032,16 @@ void FPromptShutdown(void)
 	if(p == NULL)
 	    return;
 
-	GTK_WIDGET_DESTROY(p->shadow)
-	GTK_WIDGET_DESTROY(p->cancel_btn)
-	GTK_WIDGET_DESTROY(p->ok_btn)
-	GTK_WIDGET_DESTROY(p->browse_btn)
-	GTK_WIDGET_DESTROY(p->entry)
-	GTK_WIDGET_DESTROY(p->label)
-	GTK_WIDGET_DESTROY(p->main_hbox)
-	GTK_WIDGET_DESTROY(p->toplevel)
+	GTK_WIDGET_DESTROY(p->shadow);
+	GTK_WIDGET_DESTROY(p->cancel_btn);
+	GTK_WIDGET_DESTROY(p->ok_btn);
+	GTK_WIDGET_DESTROY(p->browse_btn);
+	GTK_WIDGET_DESTROY(p->entry);
+	GTK_WIDGET_DESTROY(p->label);
+	GTK_WIDGET_DESTROY(p->main_hbox);
+	GTK_WIDGET_DESTROY(p->toplevel);
 
-	GDK_PIXMAP_UNREF(p->shadow_pm)
+	GDK_PIXMAP_UNREF(p->shadow_pm);
 
 	fprompt = NULL;
 	g_free(p);
