@@ -131,8 +131,6 @@ typedef enum {
  (_c_)->blue	= (gushort)((gfloat)(_b_) * m);		\
 } }
 
-#define GDK_COLORMAP_UNREF(_cmap_)	\
-{ if((_cmap_) != NULL) gdk_colormap_unref(_cmap_); }
 #define GDK_COLORMAP_ALLOC_COLOR(_cmap_,_c_)	\
 { if(((_cmap_) != NULL) && ((_c_) != NULL))	\
  gdk_colormap_alloc_color((_cmap_), (_c_), TRUE, TRUE); \
@@ -159,15 +157,27 @@ typedef enum {
  *	GdkFont, GdkBitmap, GdkPixmap, GdkCursor, and GdkGC
  *	Macros:
  */
+#define GDK_FONT_REF(_p_)	\
+{ if((_p_) != NULL) gdk_font_ref(_p_); }
 #define GDK_FONT_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_font_unref(_p_); }
+#define GDK_COLORMAP_REF(_p_)	\
+{ if((_p_) != NULL) gdk_colormap_ref(_p_); }
+#define GDK_COLORMAP_UNREF(_p_)	\
+{ if((_p_) != NULL) gdk_colormap_unref(_p_); }
+#define GDK_BITMAP_REF(_p_)	\
+{ if((_p_) != NULL) gdk_bitmap_ref(_p_); }
 #define GDK_BITMAP_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_bitmap_unref(_p_); }
+#define GDK_PIXMAP_REF(_p_)	\
+{ if((_p_) != NULL) gdk_pixmap_ref(_p_); }
 #define GDK_PIXMAP_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_pixmap_unref(_p_); }
 #define GDK_CURSOR_DESTROY(_p_)	\
 { if((_p_) != NULL) gdk_cursor_destroy(_p_); }
-#define GDK_GC_UNREF(_p_)		\
+#define GDK_GC_REF(_p_)		\
+{ if((_p_) != NULL) gdk_gc_ref(_p_); }
+#define GDK_GC_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_gc_unref(_p_); }
 
 
@@ -342,8 +352,6 @@ extern void GUISetWMIconFile(GdkWindow *window, const gchar *filename);
 
 
 /* GtkWindow Utilities */
-#define gtk_window_queue_optimal_resize	GUIWindowQueueOptimalResize
-extern void GUIWindowQueueOptimalResize(GtkWindow *w);
 #define gtk_window_apply_args GUIWindowApplyArgs
 extern void GUIWindowApplyArgs(GtkWindow *w, gint argc, gchar **argv);
 
@@ -365,10 +373,10 @@ extern GdkBitmap *GUICreateBitmapFromDataRGBA(
 /* Pixmap Utilities */
 extern GdkPixmap *GDK_PIXMAP_NEW(gint width, gint height);
 extern GdkPixmap *GDK_PIXMAP_NEW_FROM_XPM_DATA(
-        GdkBitmap **mask_rtn, guint8 **data
+	GdkBitmap **mask_rtn, guint8 **data
 ); 
 extern GdkPixmap *GDK_PIXMAP_NEW_FROM_XPM_FILE(
-        GdkBitmap **mask_rtn, const gchar *filename
+	GdkBitmap **mask_rtn, const gchar *filename
 );
 extern GtkWidget *gtk_pixmap_new_from_xpm_d(
 	GdkWindow *window, GdkColor *transparent_color,            
@@ -394,6 +402,7 @@ extern void GUISetGlobalTipsState(gboolean state);
 extern void GUIButtonChangeLayout(
 	GtkWidget *w, gboolean show_pixmap, gboolean show_label
 );
+extern void GUIButtonLabelUnderline(GtkWidget *w, guint c);
 extern void GUIButtonPixmapUpdate(
 	GtkWidget *w, guint8 **icon, const gchar *label
 );
@@ -546,8 +555,9 @@ extern GtkWidget *GUIMenuItemCreate(
 	guint accel_key, guint accel_mods,
 	gpointer *functional_widget_rtn,
 	gpointer data,
-	void (*func_cb)(GtkWidget *w, void *)
+	void (*func_cb)(GtkWidget *w, gpointer)
 );
+extern void GUISetMenuItemDefault(GtkWidget *w);
 extern void GUISetMenuItemCrossingCB(
 	GtkWidget *w,
 	gint (*enter_cb)(GtkWidget *, GdkEvent *, gpointer),
@@ -562,6 +572,14 @@ extern GtkWidget *GUIMenuAddToMenuBar(
 );
 extern void GUIMenuItemSetLabel(GtkWidget *menu_item, const gchar *label);
 extern void GUIMenuItemSetPixmap(GtkWidget *menu_item, guint8 **icon_data);
+extern void GUIMenuItemSetAccelKey(
+	GtkWidget *menu_item, GtkAccelGroup *accelgrp,
+	guint accel_key, guint accel_mods
+);
+extern void GUIMenuItemSetCheck(
+	GtkWidget *menu_item, gboolean active, gboolean emit
+);
+extern gboolean GUIMenuItemGetCheck(GtkWidget *menu_item);
 extern GtkWidget *GUIMenuAddToMenuBarPixmapH(
 	GtkWidget *menu_bar, GtkWidget *menu,
 	const gchar *label, guint8 **icon_data,
