@@ -52,16 +52,16 @@ medit_core_struct *context_core_ptr = NULL;
 gboolean use_text_delete;
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -142,7 +142,7 @@ static gboolean load_font_to_style(GtkStyle *style_ptr, const gchar *font_name)
 	/* Set newly loaded font to style */
 	style_ptr->font = new_font;
 
-	return(FALSE);  
+	return(FALSE);
 }
 
 
@@ -338,7 +338,7 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 	    /* Heading 2 reverse */
 	    style_ptr = gtk_style_copy(style_standard);
 	    if(style_ptr != NULL)
-	    {       
+	    {
 		c = style_ptr->fg[GTK_STATE_NORMAL];
 		style_ptr->fg[GTK_STATE_NORMAL] =   
 		    style_ptr->bg[GTK_STATE_NORMAL];
@@ -534,7 +534,7 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 
 	    pixmap = &pixmaps_list->manpage_section_20x20;
 	    mask = &pixmaps_list->manpage_section_20x20_mask;
-	    data = (u_int8_t **)icon_manpage_section_20x20_xpm;   
+	    data = (u_int8_t **)icon_manpage_section_20x20_xpm;
 	    DO_LOAD_PIXMAP
 
 #undef DO_LOAD_PIXMAP
@@ -656,7 +656,7 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 	      
 	    viewer_num = core_ptr->total_viewers;
 	    core_ptr->total_viewers++;
-	    core_ptr->viewer = (viewer_struct **)g_realloc(  
+	    core_ptr->viewer = (viewer_struct **)g_realloc(
 		core_ptr->viewer,
 		core_ptr->total_viewers * sizeof(viewer_struct *)
 	    );
@@ -710,7 +710,7 @@ gint MEditManage(gpointer data)
 	viewer_struct *viewer;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	medit_core_struct *core_ptr = (medit_core_struct *)data;
 	if(core_ptr == NULL)
 	    return(FALSE);
@@ -755,7 +755,7 @@ gint MEditManage(gpointer data)
 	    if(PDialogIsQuery())
 	    {
 		PDialogBreakQuery();
-		reenterant = FALSE;  
+		reenterant = FALSE;
 		return(TRUE);
 	    }
 	    /* All dialogs not in query */
@@ -819,11 +819,11 @@ gint MEditManage(gpointer data)
 		    branch = EditorItemGetFirstToplevel(editor);
 		    while(branch != NULL)
 		    {
-			item_ptr = EditorBranchGetData(
+			item = EditorBranchGetData(
 			    (GtkCTree *)editor->layout_ctree,
 			    branch
 			);
-			if(item_ptr->has_changes)
+			if(item->has_changes)
 			{
 			    need_break = TRUE;
 			    break;
@@ -947,7 +947,7 @@ you can say yes to exit and discard those changes.",
 		    continue;
 
 		/* Is this viewer initialized and mapped? */
-		if(viewer->initialized && viewer->map_state)     
+		if(viewer->initialized && viewer->map_state)
 		    break;
 	    }
 	    /* Atleast one viewer was initialized and mapped? */
