@@ -1,13 +1,11 @@
 /*
-                  Manual Page Editor Core: Callbacks
+		  Manual Page Editor Core: Callbacks
  */
 #ifndef MANEDITCB_H
 #define MANEDITCB_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
 
-#include "manedit.h"
 
 extern void MEditHelpManPageProceduresCB(GtkWidget *widget, gpointer data);
 extern void MEditHelpManPageXMLRefCB(GtkWidget *widget, gpointer data);
@@ -17,4 +15,5 @@ extern void MEditAboutDialogMapCB(GtkWidget *widget, gpointer data);
 extern void MEditEditorNewCB(GtkWidget *widget, gpointer data);
 extern void MEditViewerNewCB(GtkWidget *widget, gpointer data);
 
+
 #endif	/* MANEDITCB_H */
