@@ -12,7 +12,7 @@
 
 extern about_dialog_struct *MEditAboutDialogNew(medit_core_struct *core_ptr);
 extern GtkWidget *MEditCreateHelpMenu(
-	medit_core_struct *core_ptr, gpointer accel_group
+	medit_core_struct *core_ptr, GtkAccelGroup *accel_group
 );
 extern gchar *MEditCreateTempDir(medit_core_struct *core_ptr);
 extern gint MEditExecuteFmtBlock(
