@@ -1,7 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #ifdef HAVE_GZIP
 #include <zlib.h>
@@ -692,7 +691,7 @@ static void MPLoadExplodeParseMPFmt(
  *	then returns a reallocated buffer. Basically doing the opposite
  *	of MPLoadExplodeParseMPFmt() but does not concatinate any lines.
  *
- *	The given buffer should no longer be referanced after this call.
+ *	The given buffer should no longer be referenced after this call.
  *
  *      Inputs are assumed valid.
  */
@@ -748,7 +747,7 @@ static char *MPSaveFormatMP(char *line_ptr)
  *	Inputs assumed valid.
  *
  *	Returns a reallocated string from buf, the given buf should no
- *	longer be referanced. The sub_start will be a pointer to a pointer
+ *	longer be referenced. The sub_start will be a pointer to a pointer
  *	in buf in which the substitution should start at. If a
  *	substitution is made then sub_start will be set to the pointer
  *	in the new buffer after the substituted segment, otherwise if no
