@@ -11,7 +11,6 @@
 
 #include "pref.h"
 #include "prefcb.h"
-
 #include "manedit.h"
 #include "maneditcb.h"
 #include "messages.h"
@@ -53,14 +52,14 @@ float PrefParmGetValueF(
 	pref_struct *pref,
 	gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
-gboolean PrefParmGetValueB(  
+gboolean PrefParmGetValueB(
 	pref_struct *pref,
 	gint parameter		/* One of MEDIT_PREF_PARM_* */
 );
 
 void PrefBranchSetData(
 	GtkCTree *ctree, GtkCTreeNode *branch,
-	pref_item_struct *item_ptr, GtkDestroyNotify destroy
+	pref_item_struct *item, GtkDestroyNotify destroy
 );
 pref_item_struct *PrefBranchGetData(
 	GtkCTree *ctree, GtkCTreeNode *branch
@@ -73,7 +72,7 @@ GtkCTreeNode *PrefAddCatagoryBranch(
 	const gchar *catagory_name,
 	GtkCTreeNode *parent,
 	GtkCTreeNode *sibling,
-	gboolean is_leaf,   
+	gboolean is_leaf,
 	GtkWidget *panel_vbox,
 	gint catagory
 );
@@ -95,7 +94,7 @@ static void PrefCreateColorButton(
 );
 static void PrefCreateFontButton(
 	pref_struct *pref,
-	GtkWidget *parent,      /* An hbox */
+	GtkWidget *parent,	/* An hbox */
 	gint parent_border,	/* Border when pack into given parent */
 	const gchar *label,
 	const gchar *font_name,
@@ -117,11 +116,22 @@ static void PrefCreateCatagories(pref_struct *pref);
 pref_struct *PrefNew(gpointer core_ptr);
 void PrefUpdateMenus(pref_struct *pref);
 void PrefReset(pref_struct *pref, gboolean need_unmap);
-void PrefMap(pref_struct *pref);  
+void PrefMap(pref_struct *pref);
 void PrefUnmap(pref_struct *pref);
 void PrefDelete(pref_struct *pref);
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
 #define PREF_BTN_WIDTH	(100 + (2 * 3))
 #define PREF_BTN_HEIGHT	(30 + (2 * 3))
 
@@ -457,7 +467,7 @@ gboolean PrefParmGetValueB(
  */
 void PrefBranchSetData(
 	GtkCTree *ctree, GtkCTreeNode *branch,
-	pref_item_struct *item_ptr, GtkDestroyNotify destroy
+	pref_item_struct *item, GtkDestroyNotify destroy
 )
 {
 	if((ctree == NULL) || (branch == NULL))
@@ -465,9 +475,9 @@ void PrefBranchSetData(
 
 	gtk_ctree_node_set_row_data_full(
 	    ctree, branch,
-	    item_ptr, destroy
-	);   
-}  
+	    item, destroy
+	);
+}
 
 /*
  *      Returns the user set data for the given GtkCTreeNode branch.
@@ -498,7 +508,7 @@ void PrefSetBusy(pref_struct *pref)
 	if(pref == NULL)
 	    return;
 
-	core_ptr = (medit_core_struct *)pref->core_ptr;
+	core_ptr = MEDIT_CORE(pref->core_ptr);
 	if(core_ptr == NULL)
 	    return;
    
@@ -533,7 +543,7 @@ void PrefSetReady(pref_struct *pref)
 	    return;
 
 	if(GTK_WIDGET_NO_WINDOW(w))
-	    return;   
+	    return;
 	
 	gdk_window_set_cursor(w->window, NULL);
 	gdk_flush();
@@ -558,12 +568,11 @@ GtkCTreeNode *PrefAddCatagoryBranch(
 	gint catagory
 )
 {
+	gchar *text[1];
+	GtkWidget *panel_toplevel;
 	GtkCTreeNode *new_branch;
 	GtkCTree *ctree;
-	gchar *text[1];
-	pref_item_struct *item_ptr;
-	GtkWidget *panel_toplevel;
-
+	pref_item_struct *item;
 
 	if(pref == NULL)
 	    return(NULL);
@@ -590,7 +599,7 @@ GtkCTreeNode *PrefAddCatagoryBranch(
 	}
 
 	/* Copy catagory name */
-	text[0] = g_strdup((catagory_name != NULL) ?
+	text[0] = STRDUP((catagory_name != NULL) ?
 	    catagory_name : "Untitled"
 	);
 	/* Create new branch */
@@ -606,16 +615,16 @@ GtkCTreeNode *PrefAddCatagoryBranch(
 	g_free(text[0]);
 
 	/* Allocate item data for branch */
-	item_ptr = (pref_item_struct *)g_malloc0(
+	item = (pref_item_struct *)g_malloc0(
 	    sizeof(pref_item_struct)
 	);
-	if(item_ptr != NULL)
+	if(item != NULL)
 	{
-	    item_ptr->catagory = catagory;
-	    item_ptr->pref_ptr = (gpointer)pref;
+	    item->catagory = catagory;
+	    item->pref = pref;
 	    PrefBranchSetData(
 		ctree, new_branch,
-		item_ptr, PrefDestroyItem
+		item, PrefDestroyItem
 	    );
 	}
 
@@ -626,9 +635,9 @@ GtkCTreeNode *PrefAddCatagoryBranch(
 /*
  *	Creates a banner like heading for the headings of pref panels.
  */
-static void PrefCreateHeading(  
+static void PrefCreateHeading(
 	pref_struct *pref,
-	GtkWidget *parent,      /* An hbox */
+	GtkWidget *parent,	/* An hbox */
 	gint parent_border,	/* Border when pack into given parent */
 	const gchar *label
 )
@@ -638,7 +647,7 @@ static void PrefCreateHeading(
 	medit_core_struct *core_ptr;
 	medit_styles_list_struct *styles_list;
 
-	core_ptr = (medit_core_struct *)pref->core_ptr;
+	core_ptr = MEDIT_CORE(pref->core_ptr);
 	if(core_ptr == NULL)
 	    return;
 
@@ -774,7 +783,7 @@ static void PrefCreateFontButton(
 	{
 	    w = gtk_label_new(label);
 	    gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
-	    gtk_widget_set_usize(w, label_width, -1);   
+	    gtk_widget_set_usize(w, label_width, -1);
 	    gtk_widget_show(w);
 	}
 
@@ -853,7 +862,7 @@ static void PrefCreatePanelApperance(pref_struct *pref, GtkWidget *parent)
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Editor check button */  
+	/* Editor check button */
 	w = gtk_check_button_new_with_label("Editor");
 	gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, border_major);
 	gtk_widget_show(w);
@@ -1059,7 +1068,7 @@ static void PrefCreatePanelFonts(pref_struct *pref, GtkWidget *parent)
 	
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent2), w);
-	gtk_widget_show(w);  
+	gtk_widget_show(w);
 	parent2 = w;
 
 	w = gtk_vbox_new(FALSE, 0);
@@ -1102,7 +1111,7 @@ static void PrefCreatePanelFonts(pref_struct *pref, GtkWidget *parent)
 	);
 
 
-	/* ManPage output underline */  
+	/* ManPage output underline */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, border_minor);
 	gtk_widget_show(w);
@@ -1170,7 +1179,7 @@ static void PrefCreatePanelColors(pref_struct *pref, GtkWidget *parent)
 
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, border_major);
-	gtk_widget_show(w);   
+	gtk_widget_show(w);
 	parent2 = w;
 
 
@@ -1248,7 +1257,7 @@ static void PrefCreatePanelColors(pref_struct *pref, GtkWidget *parent)
 
 
 	/* Tag text */
-	w = gtk_hbox_new(FALSE, 0);   
+	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, border_minor);
 	gtk_widget_show(w);
 	parent3 = w;
@@ -1288,7 +1297,7 @@ static void PrefCreatePanelColors(pref_struct *pref, GtkWidget *parent)
 	parent2 = w;
 
 	w = gtk_frame_new("ManPage Output");
-	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, border_major);  
+	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, border_major);
 	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_ETCHED_IN);
 	gtk_widget_show(w);
 	parent2 = w;
@@ -1643,20 +1652,19 @@ static void PrefCreatePanelLocations(pref_struct *pref, GtkWidget *parent)
 	heading[1] = "Label";
 	w = gtk_clist_new_with_titles(2, heading);
 	clist = GTK_CLIST(w);
-/*
+#if 0
 	if(!GTK_WIDGET_NO_WINDOW(w))
 	{
 	    gtk_widget_set_events(
 		w,
 		GDK_BUTTON_PRESS_MASK
 	    );
-	    gtk_signal_connect_after(  
+	    gtk_signal_connect_after(
 		GTK_OBJECT(w), "button_press_event",
-		GTK_SIGNAL_FUNC(EditorFIPMenuMapCB),
-		(gpointer)fip
+		GTK_SIGNAL_FUNC(EditorFIPMenuMapCB), fip
 	    );
 	}
- */
+#endif
 	gtk_clist_set_selection_mode(clist, GTK_SELECTION_SINGLE);
 	gtk_clist_set_row_height(clist, MEDIT_LIST_ROW_SPACING);
 /*      gtk_clist_set_auto_sort(clist, TRUE); */
@@ -1900,7 +1908,7 @@ static void PrefCreateCatagories(pref_struct *pref)
 
 	/* Editor */
 	parent = gtk_vbox_new(FALSE, 0);
-	branch = PrefAddCatagoryBranch(  
+	branch = PrefAddCatagoryBranch(
 	    pref, "Editor",
 	    NULL, NULL,
 	    TRUE,		/* Is leaf */
@@ -1961,9 +1969,9 @@ pref_struct *PrefNew(gpointer core_ptr)
 	GtkWidget *scroll_parent;
 	GtkCList *clist;
 	gchar *title[1];
-	pref_struct *pref = (pref_struct *)g_malloc0(
+	pref_struct *pref = PREF(g_malloc0(
 	    sizeof(pref_struct)
-	);
+	));
 	if(pref == NULL)
 	    return(NULL);
 
@@ -2028,7 +2036,7 @@ pref_struct *PrefNew(gpointer core_ptr)
 	parent2 = w;
 
 
-	/* Vbox for layout ctree */  
+	/* Vbox for layout ctree */
 	w = gtk_vbox_new(FALSE, 0);
 	gtk_paned_add1(GTK_PANED(parent2), w);
 	gtk_widget_show(w);
@@ -2330,7 +2338,7 @@ void PrefMap(pref_struct *pref)
 	    return;
 
 	if(!pref->map_state)
-	{   
+	{
 	    pref->map_state = TRUE;
 	    gtk_widget_show(w);
 	}
