@@ -15,7 +15,6 @@
 #include "pref.h"
 #include "prefcb.h"
 #include "prefop.h"
-
 #include "manedit.h"
 
 
@@ -61,27 +60,28 @@ void PrefManPageDirsCListUnselectCB(
 );
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
- *	Deletes the pref_item_struct structure.
+ *	Item destroy callback.
  */
 void PrefDestroyItem(gpointer data)
 {
-	pref_struct *pref;
-	pref_item_struct *item_ptr = (pref_item_struct *)data;
-	if(item_ptr == NULL)
+	pref_item_struct *item = PREF_ITEM(data);
+	if(item == NULL)
 	    return;
 
-	pref = (pref_struct *)item_ptr->pref_ptr;
-
-	/* Delete preference window catagory ctree branch item data
-	 * itself
-	 */
-	g_free(item_ptr);
+	g_free(item);
 }
 
 
@@ -92,12 +92,11 @@ void PrefDestroyItem(gpointer data)
  */
 void PrefDrawingAreaDestroyCB(GtkObject *object, gpointer data)
 {
-	csd_color_struct *color_ptr = (csd_color_struct *)data;
-	if(color_ptr == NULL)
+	csd_color_struct *c = (csd_color_struct *)data;
+	if(c == NULL)
 	    return;
 
-	/* Delete csd_color_struct */
-	g_free(color_ptr);
+	g_free(c);
 }
 
 /*
@@ -114,7 +113,7 @@ void PrefDestroyCB(GtkObject *widget, gpointer data)
 gint PrefCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
 	static gboolean reenterant = FALSE;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if(pref == NULL)
 	    return(TRUE);
 
@@ -154,7 +153,7 @@ void PrefCloseMCB(GtkWidget *widget, gpointer data)
  */
 void PrefOKCB(GtkWidget *widget, gpointer data)
 {
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if(pref == NULL)
 	    return;
 
@@ -170,7 +169,7 @@ void PrefOKCB(GtkWidget *widget, gpointer data)
  */     
 void PrefApplyCB(GtkWidget *widget, gpointer data)
 {       
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if(pref == NULL)
 	    return;
 
@@ -184,7 +183,7 @@ void PrefApplyCB(GtkWidget *widget, gpointer data)
  */     
 void PrefSaveCB(GtkWidget *widget, gpointer data)
 {
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if(pref == NULL)
 	    return;
 
@@ -282,9 +281,7 @@ void PrefSelectFontCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	/* Get font name from entry widget, and make a copy */
-	font_name = gtk_entry_get_text(entry);
-	if(font_name != NULL)
-	    font_name = g_strdup(font_name);
+	font_name = STRDUP(gtk_entry_get_text(entry));
 
 	if(FSDGetResponse(
 	    "Select Font",
@@ -332,9 +329,7 @@ void PrefBrowsePathCB(GtkWidget *widget, gpointer data)
 	    reenterant = TRUE;
 
 	/* Record old path, as a coppied string */
-	old_path = gtk_entry_get_text(entry);
-	if(old_path != NULL)
-	    old_path = g_strdup(old_path);
+	old_path = STRDUP(gtk_entry_get_text(entry));
 
 	/* Parse old path */
 	if(old_path != NULL)
@@ -413,9 +408,9 @@ void PrefCatagoryCTreeSelectCB(
 	static gboolean reenterant = FALSE;
 	gint row;
 	GtkCList *clist;
-	pref_item_struct *item_ptr; 
+	pref_item_struct *item; 
 	GtkWidget *panel_parent;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((pref == NULL) || (ctree == NULL))
 	    return;
 
@@ -459,16 +454,16 @@ void PrefCatagoryCTreeSelectCB(
 	    if(branch != NULL)
 	    {
 		/* Get catagory branch item pointer */
-		item_ptr = PrefBranchGetData(
+		item = PrefBranchGetData(
 		    ctree, branch
 		);
-		if(item_ptr != NULL)
+		if(item != NULL)
 		{
 		    /* Get panel parent widget corresponding to the
 		     * catagory index
 		     */
 		    panel_parent = PrefPanelGetWidget(
-			pref, item_ptr->catagory
+			pref, item->catagory
 		    );
 
 		    /* Unmap panel parent */
@@ -494,9 +489,9 @@ void PrefCatagoryCTreeUnselectCB(
 )
 {
 	static gboolean reenterant = FALSE;
-	pref_item_struct *item_ptr;
+	pref_item_struct *item;
 	GtkWidget *panel_parent;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((pref == NULL) || (ctree == NULL))
 	    return;
 
@@ -508,16 +503,16 @@ void PrefCatagoryCTreeUnselectCB(
 	if((gpointer)ctree == (gpointer)pref->catagory_ctree)
 	{
 	    /* Get catagory branch item pointer */
-	    item_ptr = PrefBranchGetData(
+	    item = PrefBranchGetData(
 		ctree, branch
 	    );
-	    if(item_ptr != NULL)
+	    if(item != NULL)
 	    {
 		/* Get panel parent widget corresponding to the
 		 * catagory index.
 		 */
 		panel_parent = PrefPanelGetWidget(
-		    pref, item_ptr->catagory
+		    pref, item->catagory
 		);
 
 		/* Unmap panel parent */
@@ -544,7 +539,7 @@ void PrefCatagoryCTreeExpandCB(
 )
 {
 	static gboolean reenterant = FALSE;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((pref == NULL) || (ctree == NULL))
 	    return;
 
@@ -583,7 +578,7 @@ gchar *PrefManPageDirPromptBrowseCB(
 	gchar **path_rtn;
 	gint path_total_rtns;
 	fb_type_struct *ext_type_rtn;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	static gchar rtn_path[PATH_MAX + NAME_MAX];
 	if(pref == NULL)
 	    return(NULL);
@@ -596,10 +591,10 @@ gchar *PrefManPageDirPromptBrowseCB(
 
 	/* Get old path, coppied */
 	s = PDialogGetPromptValue(prompt_num);
-	old_path = g_strdup((s != NULL) ? s : "");
+	old_path = STRDUP((s != NULL) ? s : "");
 
 	/* Reset return path */
-	(*rtn_path) = '\0';
+	*rtn_path = '\0';
 
 	/* Allocate file extension types list */
 	ext_type = NULL;
@@ -652,7 +647,7 @@ void PrefManPageDirsAddCB(GtkWidget *widget, gpointer data)
 	gchar **response_value;
 	gint total_response_values;
 	GtkCList *clist;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
 	    return;
 
@@ -765,7 +760,7 @@ void PrefManPageDirsEditCB(GtkWidget *widget, gpointer data)
 	gint total_response_values;
 	GtkCList *clist;
 	gchar *cur_path, *cur_label;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
 	    return;
 
@@ -794,13 +789,11 @@ void PrefManPageDirsEditCB(GtkWidget *widget, gpointer data)
 	/* Get current values of row from clist, coppied */
 	if(!gtk_clist_get_text(clist, row, 0, &cur_path))
 	    cur_path = NULL;
-	if(cur_path != NULL)
-	    cur_path = g_strdup(cur_path);
+	cur_path = STRDUP(cur_path);
 
 	if(!gtk_clist_get_text(clist, row, 1, &cur_label))
 	    cur_label = NULL;
-	if(cur_label != NULL)
-	    cur_label = g_strdup(cur_label);
+	cur_label = STRDUP(cur_label);
 
 
 	PDialogDeleteAllPrompts();
@@ -878,7 +871,7 @@ void PrefManPageDirsRemoveCB(GtkWidget *widget, gpointer data)
 	static gboolean reenterant = FALSE;
 	gint status, row;
 	GtkCList *clist;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
 	    return;
  
@@ -934,7 +927,7 @@ void PrefManPageDirsCListSelectCB(
 {
 	static gboolean reenterant = FALSE;
 	GtkWidget *w;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
 	    return;
 
@@ -963,7 +956,7 @@ void PrefManPageDirsCListUnselectCB(
 {
 	static gboolean reenterant = FALSE;
 	GtkWidget *w;
-	pref_struct *pref = (pref_struct *)data;
+	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
 	    return;
 
