@@ -7,6 +7,7 @@
 #include "pulist.h"
 
 
+/* Popup List Callbacks */
 static gint PUListDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
@@ -32,29 +33,69 @@ static void PUListShadowConfigure(
 static void PUListCListDoDragSetUp(pulist_struct *list);
 static void PUListCListDoDragCleanUp(pulist_struct *list);
 
+
+/* Map Button Callbacks */
 static gint PUListMapButtonExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
 );
 
+
+/* Popup List Box Callbacks */
+static gint PUListBoxEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
+);
+static void PUListBoxMapCB(GtkWidget *widget, gpointer data);
+static void PUListBoxDraw(pulistbox_struct *box);
+
+
+/* Popup List */
+gint PUListFindItemFromValue(pulist_struct *list, const gchar *value);
 gpointer PUListGetDataFromValue(
 	pulist_struct *list, const gchar *value
 );
 GtkWidget *PUListGetToplevel(pulist_struct *list);
 GtkWidget *PUListGetCList(pulist_struct *list);
 
-void PUListAddItem(
-	pulist_struct *list, const gchar *value,
-	gpointer client_data, GtkDestroyNotify destroy_cb
+gint PUListAddItem(
+	pulist_struct *list, const gchar *value
 );
-void PUListAddItemPixText(
+gint PUListAddItemPixText(
 	pulist_struct *list, const gchar *value,
-	GdkPixmap *pixmap, GdkBitmap *mask,
-	gpointer client_data, GtkDestroyNotify destroy_cb
+	GdkPixmap *pixmap, GdkBitmap *mask
 );
 void PUListClear(pulist_struct *list);
 
+void PUListSetItemText(
+	pulist_struct *list, gint i,
+	const gchar *value
+);
+void PUListSetItemPixText(
+	pulist_struct *list, gint i,
+	const gchar *value,
+	GdkPixmap *pixmap, GdkBitmap *mask
+);
+void PUListSetItemData(
+	pulist_struct *list, gint i,
+	gpointer data
+);
+void PUListSetItemDataFull(
+	pulist_struct *list, gint i,
+	gpointer data, GtkDestroyNotify destroy_cb
+);
+
+void PUListGetItemText(
+	pulist_struct *list, gint i,
+	gchar **value 
+);
+void PUListGetItemPixText(
+	pulist_struct *list, gint i,
+	gchar **value,
+	GdkPixmap **pixmap, GdkBitmap **mask 
+);
+gpointer PUListGetItemData(pulist_struct *list, gint i);
+
 gint PUListGetSelectedLast(pulist_struct *list);
-void PUListSelect(pulist_struct *list, gint row);
+void PUListSelect(pulist_struct *list, gint i);
 void PUListUnselectAll(pulist_struct *list);
 
 gboolean PUListIsQuery(pulist_struct *list);
@@ -71,17 +112,41 @@ const gchar *PUListMapQuery(
 pulist_struct *PUListNew(void);
 void PUListDelete(pulist_struct *list);
 
+
+/* Map Button */
 GtkWidget *PUListNewMapButton(
 	void (*map_cb)(GtkWidget *, gpointer),
 	gpointer client_data
 );
 GtkWidget *PUListNewMapButtonArrow(
-	gint arrow_type, gint shadow_type,
+	GtkArrowType arrow_type, GtkShadowType shadow_type,
 	void (*map_cb)(GtkWidget *, gpointer),
 	gpointer client_data
 );
 
 
+/* Popup List Box */
+GtkWidget *PUListBoxGetToplevel(pulistbox_struct *box);
+pulist_struct *PUListBoxGetPUList(pulistbox_struct *box);
+
+pulistbox_struct *PUListBoxNew(
+	GtkWidget *parent,
+	gint width, gint height
+);
+void PUListBoxSetChangedCB(
+	pulistbox_struct *box,
+	void (*func)(
+		pulistbox_struct *,	/* Popup List Box */
+		gint,			/* Item */
+		gpointer		/* Data */
+	),
+	gpointer data
+);
+void PUListBoxMap(pulistbox_struct *box);
+void PUListBoxUnmap(pulistbox_struct *box);
+void PUListBoxDelete(pulistbox_struct *box);
+
+
 #define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
@@ -807,37 +872,351 @@ static gint PUListMapButtonExposeCB(
 
 
 /*
- *	Returns the data that matches the specified value on the
- *	Popup List.
+ *	Popup List Box GtkDrawingArea event signal callback.
  */
-gpointer PUListGetDataFromValue(
-	pulist_struct *list, const gchar *value
+static gint PUListBoxEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
 )
 {
-	gint row;
-	gchar *cell_text;
+	gint status = FALSE;
+	gboolean key_press;
+	GdkEventFocus *focus;
+	GdkEventKey *key;
+	GdkEventButton *button;
+	pulistbox_struct *box = PULISTBOX(data);
+	if((widget == NULL) || (event == NULL) || (box == NULL))
+	    return(status);
+
+	switch((gint)event->type)
+	{
+	  case GDK_EXPOSE:
+	    PUListBoxDraw(box);
+	    status = TRUE;
+	    break;
+
+	  case GDK_FOCUS_CHANGE:
+	    focus = (GdkEventFocus *)event;
+	    if(focus->in && !GTK_WIDGET_HAS_FOCUS(widget))
+	    {
+		GTK_WIDGET_SET_FLAGS(widget, GTK_HAS_FOCUS);
+		gtk_widget_queue_draw(widget);
+		status = TRUE;
+	    }
+	    else if(!focus->in && GTK_WIDGET_HAS_FOCUS(widget))
+	    {
+		GTK_WIDGET_UNSET_FLAGS(widget, GTK_HAS_FOCUS);
+		gtk_widget_queue_draw(widget);
+		status = TRUE;
+	    }
+	    break;
+
+	  case GDK_KEY_PRESS:
+	  case GDK_KEY_RELEASE:
+	    key = (GdkEventKey *)event;
+	    key_press = (key->type == GDK_KEY_PRESS) ? TRUE : FALSE;
+#define STOP_KEY_SIGNAL_EMIT    {               \
+if(widget != NULL)                              \
+ gtk_signal_emit_stop_by_name(                  \
+  GTK_OBJECT(widget),                           \
+  key_press ?                                   \
+   "key_press_event" : "key_release_event"      \
+ );                                             \
+}
+	    switch(key->keyval)
+	    {
+	      case GDK_Return:
+	      case GDK_KP_Enter:
+	      case GDK_space:
+		if(key_press)
+		    PUListBoxMapCB(box->map_btn, box);
+		STOP_KEY_SIGNAL_EMIT
+		status = TRUE; 
+		break;
+
+	      case GDK_Up:
+	      case GDK_KP_Up:
+		if(key_press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			gint row = (glist != NULL) ? (gint)glist->data : -1;
+			if(row < 0)
+			    row = 0;
+			else 
+			    row--;
+			if((row >= 0) && (row < clist->rows))
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT
+		status = TRUE;
+		break;
+
+	      case GDK_Down:
+	      case GDK_KP_Down:
+		if(key_press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			gint row = (glist != NULL) ? (gint)glist->data : -1;
+			if(row < 0)
+			    row = 0;
+			else
+			    row++;
+			if((row >= 0) && (row < clist->rows))
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT
+		status = TRUE;
+		break;
+	    }
+	    break;
+
+	  case GDK_BUTTON_PRESS:
+	    button = (GdkEventButton *)event;
+	    if(!GTK_WIDGET_HAS_FOCUS(widget))
+		gtk_widget_grab_focus(widget);
+	    if(button->button == 1)
+		PUListBoxMapCB(box->map_btn, box);
+	    status = TRUE;
+	    break;
+	}
+
+	return(status);
+}
+
+/*
+ *	Popup List Box map callback.
+ */
+static void PUListBoxMapCB(GtkWidget *widget, gpointer data)
+{
+	const gchar *v;
+	pulist_struct *list;
+	pulistbox_struct *box = PULISTBOX(data);
+	if((widget == NULL) || (box == NULL))
+	    return;
+
+	list = PUListBoxGetPUList(box);
+	if(list == NULL)
+	    return;
+
+	/* Map Popup List and wait for user response */
+	v = PUListMapQuery(
+	    list,
+	    NULL,		/* Initial value */
+	    -1,			/* Lines visible */
+	    PULIST_RELATIVE_BELOW,
+	    box->toplevel,
+	    widget
+	);
+
+	/* Got new value? */
+	if(v != NULL)
+	{
+	    gint i = PUListFindItemFromValue(list, v);
+
+	    gtk_widget_queue_draw(box->da);
+
+	    /* Report new value */
+	    if(box->changed_cb != NULL)
+		box->changed_cb(
+		    box,		/* Popup List Box */
+		    i,			/* Item */
+		    box->changed_data	/* Data */
+		);
+	}
+}
+
+/*
+ *	Redraws the Popup List Box.
+ */
+static void PUListBoxDraw(pulistbox_struct *box)
+{
+	const gint	frame_border = 2;
+	gint width, height, font_height;
+	GdkFont *font;
+	GdkDrawable *drawable;
+	GdkWindow *window;
+	GtkStateType state;
+	GtkStyle *style;
+	pulist_struct *list;
+	GtkWidget *w = (box != NULL) ? box->da : NULL;
+	if(w == NULL)
+	    return;
+
+	window = w->window;
+	state = GTK_WIDGET_STATE(w);
+	style = gtk_widget_get_style(w);
+	list = PUListBoxGetPUList(box);
+	if((window == NULL) || (style == NULL) || (list == NULL))
+	    return;
+
+	gdk_window_get_size(window, &width, &height);
+	font = style->font;
+	if((font == NULL) || (width <= 0) || (height <= 0))
+	    return;
+		   
+	font_height = font->ascent + font->descent;
+
+	drawable = (GdkDrawable *)window;
+
+	/* Draw background */
+	gdk_draw_rectangle(
+	    drawable, style->base_gc[state], TRUE,
+	    0, 0, width, height
+	);
+
+	/* Draw value */
+	if(list->clist != NULL)
+	{
+	    /* Get selected row or first row */
+	    GdkGC *gc = style->text_gc[state];
+	    GtkCList *clist = GTK_CLIST(list->clist);
+	    GList *glist = clist->selection_end;
+	    gint row = (glist != NULL) ? (gint)glist->data : 0;
+
+	    if((row >= 0) && (row < clist->rows))
+	    {
+		gint x = frame_border, y;
+		gchar *text = NULL;
+		guint8 spacing = 0;
+		GdkPixmap *pixmap = NULL;
+		GdkBitmap *mask = NULL;
+
+		/* Get icon and text */
+		switch(gtk_clist_get_cell_type(clist, row, 0))
+		{
+		  case GTK_CELL_TEXT:
+		    gtk_clist_get_text(clist, row, 0, &text);
+		    break;
+		  case GTK_CELL_PIXTEXT:
+		    gtk_clist_get_pixtext(
+			clist, row, 0, &text,
+			&spacing, &pixmap, &mask
+		    );
+		    break;
+		  case GTK_CELL_PIXMAP:
+		    gtk_clist_get_pixmap(
+			clist, row, 0, &pixmap, &mask
+		    );
+		    break;
+		  case GTK_CELL_WIDGET:
+		  case GTK_CELL_EMPTY:
+		    break;
+		}
+		/* Draw icon? */
+		if(pixmap != NULL)
+		{
+		    gint pm_width, pm_height;
+		    gdk_window_get_size(pixmap, &pm_width, &pm_height);
+		    y = (height - pm_height) / 2;
+		    gdk_gc_set_clip_mask(gc, mask);
+		    gdk_gc_set_clip_origin(gc, x, y);
+		    gdk_draw_pixmap(
+			drawable, gc, pixmap,
+			0, 0, x, y, pm_width, pm_height
+		    );
+		    gdk_gc_set_clip_mask(gc, NULL);
+		    x += pm_width + (gint)spacing;
+		}
+		/* Draw text? */
+		if(text != NULL)
+		{
+		    GdkTextBounds b;
+		    gdk_string_bounds(font, text, &b);
+		    gdk_draw_string(
+			drawable, font, gc,
+			x - b.lbearing,
+			((height - font_height) / 2) +
+			    font->ascent,
+			text
+		    );
+		}
+	    }
+	}
+
+	/* Draw frame */
+	gtk_draw_shadow(
+	    style, drawable, state, GTK_SHADOW_IN,
+	    0, 0, width - 1, height - 1
+	);
+
+	/* Draw focus if widget is focused */
+	if(GTK_WIDGET_HAS_FOCUS(w) && GTK_WIDGET_SENSITIVE(w))
+	    gtk_draw_focus(
+		style, drawable,
+		0, 0, width - 1, height - 1
+	    );
+
+	/* Send drawable to window if drawable is not the window */
+	if(drawable != window)                                     
+	    gdk_draw_pixmap(
+		window, style->fg_gc[state], drawable,
+		0, 0, 0, 0, width, height
+	    );
+}
+
+/*
+ *	Returns the Popup List item index that matches the specified
+ *	text.
+ */
+gint PUListFindItemFromValue(pulist_struct *list, const gchar *value)
+{
+	gint i;
+	gchar *text;
 	guint8 spacing;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
 	if((clist == NULL) || (value == NULL))
-	    return(NULL);
+	    return(-1);
 
-	/* Iterate through all rows, searching for row that matches
-	 * the given value
-	 */
-	for(row = 0; row < clist->rows; row++)
+	for(i = 0; i < clist->rows; i++)
 	{
-	    cell_text = NULL;
-	    switch(gtk_clist_get_cell_type(clist, row, 0))
+	    text = NULL;
+	    switch(gtk_clist_get_cell_type(clist, i, 0))
 	    {
 	      case GTK_CELL_TEXT:
-		gtk_clist_get_text(clist, row, 0, &cell_text);
+		gtk_clist_get_text(
+		    clist, i, 0, &text
+		);
 		break;
 	      case GTK_CELL_PIXTEXT:
 		gtk_clist_get_pixtext(
-		    clist, row, 0, &cell_text,
+		    clist, i, 0, &text,
 		    &spacing, &pixmap, &mask
 		);
 		break;
@@ -846,18 +1225,33 @@ gpointer PUListGetDataFromValue(
 	      case GTK_CELL_EMPTY:
 		break;
 	    }
-	    /* Got value for current row? */
-	    if(!STRISEMPTY(cell_text))
+	    if(text != NULL)
 	    {
-		if(!strcmp(cell_text, value))
-		{
-		    /* Got match, return client data for this row */
-		    return(gtk_clist_get_row_data(clist, row));
-		}
+		if((text == value) || !strcmp(text, value))
+		    return(i);
 	    }
 	}
+	 
+	return(-1);
+}
 
-	return(NULL);
+/*
+ *	Returns the Popup List item's data that matches the
+ *	specified text.
+ */
+gpointer PUListGetDataFromValue(
+	pulist_struct *list, const gchar *value
+)
+{
+	gint i;
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if((clist == NULL) || (value == NULL))
+	    return(NULL);
+
+	i = PUListFindItemFromValue(list, value);
+	return((i >= 0) ?
+	    gtk_clist_get_row_data(clist, i) : NULL
+	);
 }
 
 /*
@@ -878,104 +1272,58 @@ GtkWidget *PUListGetCList(pulist_struct *list)
 
 
 /*
- *	Appends a new item to the Popup List.
+ *	Adds a new item to Popup List with the specified text.
  */
-void PUListAddItem(
-	pulist_struct *list, const gchar *value,
-	gpointer client_data, GtkDestroyNotify destroy_cb
+gint PUListAddItem(
+	pulist_struct *list, const gchar *value
 )
 {
-	gint i, new_row;
+	return(PUListAddItemPixText(list, value, NULL, NULL));
+}
+
+/*
+ *	Adds a new item to Popup List with the specified icon & text.
+ */
+gint PUListAddItemPixText(
+	pulist_struct *list, const gchar *value,
+	GdkPixmap *pixmap, GdkBitmap *mask
+)
+{
+	gint i;
 	gchar **strv;
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
-	if(clist == NULL)
-	    return;
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if((clist != NULL) ? (clist->columns <= 0) : TRUE)
+	    return(-1);
 
 	/* Allocate cell values for new row */
 	strv = (gchar **)g_malloc(
 	    clist->columns * sizeof(gchar *)
 	);
+	if(strv == NULL)
+	    return(-1);
 	for(i = 0; i < clist->columns; i++)
 	    strv[i] = "";
 
 	/* Append a new row */
-	new_row = gtk_clist_append(clist, strv);
+	i = gtk_clist_append(clist, strv);
 
 	/* Delete cell values */
 	g_free(strv);
 
-	/* If new row was created successfully, then set text and
-	 * client data with destroy callback
-	 */
-	if((new_row > -1) && (value != NULL))
-	{
-	    gtk_clist_set_text(clist, new_row, 0, value);
-	    gtk_clist_set_row_data_full(
-		clist, new_row, client_data, destroy_cb
-	    );
-	}
+	if(i < 0)
+	    return(-1);
+
+	PUListSetItemPixText(list, i, value, pixmap, mask);
+
+	return(i);
 }
 
 /*
- *	Same as PUListAddItem() except that it adds a pixmap and mask.
- */
-void PUListAddItemPixText(
-	pulist_struct *list, const gchar *value,
-	GdkPixmap *pixmap, GdkBitmap *mask,
-	gpointer client_data, GtkDestroyNotify destroy_cb
-)
-{
-	gint i, new_row;
-	gchar **strv;
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
-	if(clist == NULL)
-	    return;
-
-	/* If no pixmap is given then revert to calling
-	 * PUListAddItem() instead
-	 */
-	if(pixmap == NULL)
-	{
-	    PUListAddItem(list, value, client_data, destroy_cb);
-	    return;
-	}
-
-	/* Allocate cell values for new row */
-	strv = (gchar **)g_malloc(
-	    clist->columns * sizeof(gchar *)
-	);
-	for(i = 0; i < clist->columns; i++)
-	    strv[i] = "";
-
-	/* Append a new row */
-	new_row = gtk_clist_append(clist, strv);
-
-	/* Delete cell values */
-	g_free(strv);
-
-	/* If new row was created successfully, then set pixtext and
-	 * client data with destroy callback
-	 */
-	if((new_row > -1) && (value != NULL))
-	{
-	    gtk_clist_set_pixtext(
-		clist, new_row, 0, value, 2, pixmap, mask
-	    );
-	    gtk_clist_set_row_data_full(
-		clist, new_row, client_data, destroy_cb
-	    );
-	}
-}
-
-/*
- *	Clears all items in the Popup List.
+ *	Deletes all items in the Popup List.
  */
 void PUListClear(pulist_struct *list)
 {
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
 	if(clist == NULL)
 	    return;
 
@@ -986,12 +1334,188 @@ void PUListClear(pulist_struct *list)
 
 
 /*
- *	Returns the last selected item on the Popup List.
+ *	Sets the Popup List item's text.
+ */
+void PUListSetItemText(
+	pulist_struct *list, gint i,
+	const gchar *value
+)
+{
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)
+	    return;
+
+	if((i < 0) || (i >= clist->rows))
+	    return;
+
+	gtk_clist_set_text(
+	    clist, i, 0,
+	    (value != NULL) ? value : ""
+	);
+}
+
+/*
+ *	Sets the Popup List item's icon & text.
+ */
+void PUListSetItemPixText(
+	pulist_struct *list, gint i,
+	const gchar *value,
+	GdkPixmap *pixmap, GdkBitmap *mask
+)
+{
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)
+	    return;      
+
+	if((i < 0) || (i >= clist->rows))
+	    return;
+
+	if(pixmap != NULL)
+	    gtk_clist_set_pixtext(
+		clist, i, 0,
+		(value != NULL) ? value : "",
+		2, pixmap, mask
+	    );
+	else
+	    gtk_clist_set_text(
+		clist, i, 0,
+		(value != NULL) ? value : ""  
+	    );   
+}
+
+/*
+ *	Sets the Popup List item's data.
+ */
+void PUListSetItemData(
+	pulist_struct *list, gint i,
+	gpointer data
+)
+{
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)
+	    return;
+
+	if((i < 0) || (i >= clist->rows))
+	    return;
+
+	gtk_clist_set_row_data(clist, i, data);
+}
+
+/*
+ *	Sets the Popup List item's data & destroy callback.
+ */
+void PUListSetItemDataFull(
+	pulist_struct *list, gint i,
+	gpointer data, GtkDestroyNotify destroy_cb
+)
+{
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)
+	    return;
+
+	if((i < 0) || (i >= clist->rows))
+	    return;
+
+	if(destroy_cb != NULL)
+	    gtk_clist_set_row_data_full(clist, i, data, destroy_cb);
+	else
+	    gtk_clist_set_row_data(clist, i, data);
+}
+
+
+/*
+ *	Gets the Popup List item's text.
+ */
+void PUListGetItemText(
+	pulist_struct *list, gint i,
+	gchar **value
+)
+{
+	PUListGetItemPixText(list, i, value, NULL, NULL);
+}
+
+/*
+ *	Gets the Popup List item's icon & text.
+ */
+void PUListGetItemPixText(
+	pulist_struct *list, gint i,
+	gchar **value,
+	GdkPixmap **pixmap, GdkBitmap **mask
+)
+{
+	gchar *ltext = NULL;
+	guint8 lspacing = 0;
+	GdkPixmap *lpixmap = NULL;
+	GdkBitmap *lmask = NULL;
+	GtkCList *clist;
+
+	if(value != NULL)
+	    *value = NULL;
+	if(pixmap != NULL)
+	    *pixmap = NULL;
+	if(mask != NULL)
+	    *mask = NULL;
+
+	clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)
+	    return;
+
+	if((i < 0) || (i >= clist->rows))
+	    return;
+
+	switch(gtk_clist_get_cell_type(clist, i, 0))
+	{
+	  case GTK_CELL_TEXT:
+	    gtk_clist_get_text(
+		clist, i, 0, &ltext
+	    );
+	    break;
+	  case GTK_CELL_PIXTEXT:
+	    gtk_clist_get_pixtext(
+		clist, i, 0, &ltext,
+		&lspacing, &lpixmap, &lmask
+	    );
+	    break;
+	  case GTK_CELL_PIXMAP:
+	    gtk_clist_get_pixmap(
+		clist, i, 0, &lpixmap, &lmask
+	    );
+	    break;
+	  case GTK_CELL_WIDGET:
+	  case GTK_CELL_EMPTY:
+	    break;
+	}
+
+	if(value != NULL)
+	    *value = ltext;
+	if(pixmap != NULL)
+	    *pixmap = lpixmap;
+	if(mask != NULL)
+	    *mask = lmask;
+}
+
+/*
+ *	Gets the Popup List item's data.
+ */
+gpointer PUListGetItemData(pulist_struct *list, gint i)
+{
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
+	if(clist == NULL)                        
+	    return(NULL);
+
+	if((i < 0) || (i >= clist->rows))
+	    return(NULL);
+
+	return(gtk_clist_get_row_data(clist, i));
+}
+
+
+/*
+ *	Returns the last selected item index on the Popup List.
  */
 gint PUListGetSelectedLast(pulist_struct *list)
 {
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
 	GList *glist = (clist != NULL) ? clist->selection_end : NULL;
 	return((glist != NULL) ? (gint)glist->data : -1);
 }
@@ -999,24 +1523,30 @@ gint PUListGetSelectedLast(pulist_struct *list)
 /*
  *	Selects the Popup List item specified by row.
  */
-void PUListSelect(pulist_struct *list, gint row)
+void PUListSelect(pulist_struct *list, gint i)
 {
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
 	if(clist == NULL)
 	    return;
-	if((row < 0) || (row >= clist->rows))
+
+	if((i < 0) || (i >= clist->rows))
 	    return;
 
-	gtk_clist_select_row(clist, row, 0);
-	if(gtk_clist_row_is_visible(clist, row) !=
+	gtk_clist_freeze(clist);
+
+	gtk_clist_unselect_all(clist);
+	gtk_clist_select_row(clist, i, 0);
+
+	if(gtk_clist_row_is_visible(clist, i) !=
 	    GTK_VISIBILITY_FULL
 	)
 	    gtk_clist_moveto(
 		clist,
-		row, -1,	/* Row, column */
+		i, -1,	/* Row, column */
 		0.5f, 0.0f	/* Row, column */
 	    );
+
+	gtk_clist_thaw(clist);
 }
 
 /*
@@ -1024,12 +1554,13 @@ void PUListSelect(pulist_struct *list, gint row)
  */
 void PUListUnselectAll(pulist_struct *list)
 {
-	GtkCList *clist = (GtkCList *)((list != NULL) ?
-	    list->clist : NULL);
+	GtkCList *clist = (GtkCList *)PUListGetCList(list);
 	if(clist == NULL)
 	    return;
 
+	gtk_clist_freeze(clist);
 	gtk_clist_unselect_all(clist);
+	gtk_clist_thaw(clist);
 }
 
 
@@ -1077,7 +1608,7 @@ const gchar *PUListMapQuery(
 	GtkWidget *map_widget		/* Widget that mapped this list */
 )
 {
-	gint sel_row = -1;
+	gint sel_item = -1;
 	gint	x, y,
 		width = POPUP_LIST_DEF_WIDTH,
 		height = POPUP_LIST_DEF_HEIGHT;
@@ -1108,20 +1639,14 @@ const gchar *PUListMapQuery(
 	/* Get root window geometry */
 	gdk_window_get_size(root, &root_width, &root_height);
 
-	/* Get intended size of toplevel if relative widget is given */
+	/* Calculate size of list based on the size of the relative
+	 * widget
+	 */
 	w = rel_widget;
-	if((w != NULL) ? (w->window != NULL) : FALSE)
-	{
-	    gdk_window_get_size(w->window, &width, &height);
-	    height = ((lines_visible < 0) ? 10 : lines_visible) *
-		POPUP_LIST_ROW_SPACING;
-	}
-	else
-	{
-	    /* No relative widget available, use default size */
-	    height = ((lines_visible < 0) ? 10 : lines_visible) *
-		POPUP_LIST_ROW_SPACING;
-	}
+	if(w != NULL)
+	    width = w->allocation.width;
+	height = ((lines_visible < 0) ? 10 : lines_visible) *
+	    POPUP_LIST_ROW_SPACING;
 
 	/* If map widget is given, then we need to restore its state
 	 * in preparation to mapping of the popup list.
@@ -1141,79 +1666,73 @@ const gchar *PUListMapQuery(
 	    }
 	}
 
-	/* If value is given, then select row on clist that matches
-	 * the given value (if any)
+	/* If a value has been specified, then select the item that
+	 * matches the specified value
 	 */
 	w = list->clist;
 	if((w != NULL) && (value != NULL))
 	{
-	    gchar *text = NULL;
-	    guint8 spacing;
-	    GdkPixmap *pixmap;
-	    GdkBitmap *mask;
-	    gint row;
-	    GtkCList *clist = GTK_CLIST(w);
-
-	    for(row = 0; row < clist->rows; row++)
+	    sel_item = PUListFindItemFromValue(list, value);
+	    if(sel_item > -1)
 	    {
-		switch(gtk_clist_get_cell_type(clist, row, 0))
-		{
-		  case GTK_CELL_TEXT:
-		    gtk_clist_get_text(clist, row, 0, &text);
-		    break;
-		  case GTK_CELL_PIXTEXT:
-		    gtk_clist_get_pixtext(
-			clist, row, 0, &text,
-			&spacing, &pixmap, &mask
-		    );
-		    break;
-		  case GTK_CELL_PIXMAP:
-		  case GTK_CELL_WIDGET:
-		  case GTK_CELL_EMPTY:
-		    break;
-		}
-		/* Got value for current row? */
-		if(!STRISEMPTY(text))
-		{
-		    if(!strcmp(text, value))
-		    {
-			/* Got match, select row and break */
-			gtk_clist_select_row(clist, row, 0);
-			sel_row = row;
-			break;
-		    }
-		}
+		GtkCList *clist = GTK_CLIST(w);
+		gtk_clist_select_row(clist, sel_item, 0);
 	    }
 	}
 
-	/* Move toplevel to relative widget? */
-	w = rel_widget;
-	if((w != NULL) ? (w->window != NULL) : FALSE)
+	/* Move and resize the toplevel & shadow */
+	if((toplevel != NULL) && (shadow != NULL) && (root != NULL))
 	{
-	    gint wwidth, wheight;
-	    GdkWindow *window = w->window;
-
-	    gdk_window_get_root_position(window, &x, &y);
-	    gdk_window_get_size(window, &wwidth, &wheight);
-	    switch(relative)
+	    /* Relative widget specified? */
+	    w = rel_widget;
+	    if((w != NULL) ? (w->window != NULL) : FALSE)
 	    {
-	      case PULIST_RELATIVE_CENTER:
-		y = y - (height / 2) + (wheight / 2);
-		break;
-	      case PULIST_RELATIVE_UP:
-		y = y - height + wheight;
-		break;
-	      case PULIST_RELATIVE_DOWN:
-		break;
-	      case PULIST_RELATIVE_ABOVE:
-		y = y - height;
-		break;
-	      case PULIST_RELATIVE_BELOW:
-		y = y + wheight;
-		break;
-	    }
+		GdkWindow *window = w->window;
+		GtkAllocation *alloc = &w->allocation;
 
-	    /* Clip x and y coordinates */
+		/* Get coordinates of the relative widget with
+		 * respect to the desktop
+		 */
+		gdk_window_get_root_position(window, &x, &y);
+		if(GTK_WIDGET_NO_WINDOW(w))
+		{
+		    x += alloc->x;
+		    y += alloc->y;
+		}
+		/* Adjust coordinates to be appropriate to the 
+		 * specified map relativity
+		 */
+		switch(relative)
+		{
+		  case PULIST_RELATIVE_CENTER:
+		    y = y - (height / 2) + (alloc->height / 2);
+		    break;
+		  case PULIST_RELATIVE_UP:
+		    y = y - height + alloc->height;
+		    break;     
+		  case PULIST_RELATIVE_DOWN:
+		    break;
+		  case PULIST_RELATIVE_ABOVE:
+		    y = y - height;
+		    break;
+		  case PULIST_RELATIVE_BELOW:
+		    y = y + alloc->height;
+		    break;
+	        }
+	    }
+	    else
+	    {
+		/* Relative widget not specified, so get the
+		 * pointer's coordinates
+		 */
+		gint px = 0, py = 0;
+		GdkModifierType mask;
+
+		gdk_window_get_pointer(root, &px, &py, &mask);
+		x = px - (width / 2);
+		y = py - (height / 2);
+	    }
+	    /* Clip coordinates with respect to the desktop */
 	    if(x > (root_width - width))
 		x = root_width - width;
 	    if(x < 0)
@@ -1223,47 +1742,28 @@ const gchar *PUListMapQuery(
 	    if(y < 0)
 		y = 0;
 
+	    /* Move toplevel & shadow */
 	    gtk_widget_set_uposition(toplevel, x, y);
-/*		gdk_window_move(toplevel->window, x, y); */
+	    gdk_window_move(toplevel->window, x, y);
 	    gtk_widget_set_uposition(shadow, x, y);
+	    gdk_window_move(shadow->window, x, y);
+
+	    /* Resize toplevel & shadow */
+	    gtk_widget_set_usize(toplevel, width, height);
+	    gdk_window_resize(toplevel->window, width, height);
+	    gtk_widget_set_usize(shadow, width, height);
+	    gdk_window_resize(shadow->window, width, height);
+
+	    /* Notify toplevel to resize */
+/*	    gtk_widget_queue_resize(toplevel); */
 	}
-	else
-	{
-	    /* Relative widget not given, so map at root coordinates
-	     * of the current pointer position
-	     */
-	    gint px = 0, py = 0;
-	    GdkModifierType mask;
-
-	    gdk_window_get_pointer(root, &px, &py, &mask);
-	    x = px - (width / 2);
-	    y = py - (height / 2);
-
-	    /* Clip x and y coordinates */
-	    if(x > (root_width - width))
-		x = root_width - width;
-	    if(x < 0)
-		x = 0;
-	    if(y > (root_height - height))
-		y = root_height - height;
-	    if(y < 0)
-		y = 0;
-
-	    gtk_widget_set_uposition(toplevel, x, y);
-	    gtk_widget_set_uposition(shadow, x, y);
-	}
-
-	/* Set new toplevel size */
-	gtk_widget_set_usize(toplevel, width, height);
-	/* Notify toplevel to resize */
-	gtk_widget_queue_resize(toplevel);
 
 	/* Recreate shadow pixmap */
 	if(root != NULL)
 	{
 	    GdkPixmap *pixmap = GDK_PIXMAP_NEW(width, height);
 
-	    GDK_PIXMAP_UNREF(list->shadow_pm)
+	    GDK_PIXMAP_UNREF(list->shadow_pm);
 	    list->shadow_pm = pixmap;
 
 	    if(pixmap != NULL)   
@@ -1311,11 +1811,11 @@ const gchar *PUListMapQuery(
 	/* Set up the clist in preperation for dragged selecting */
 	PUListCListDoDragSetUp(list);
 
-	/* Move to selected row (if any) */
-	if((list->clist != NULL) && (sel_row > -1))
+	/* Move list scroll to the selected item (if any) */
+	if((list->clist != NULL) && (sel_item > -1))
 	    gtk_clist_moveto(
 		GTK_CLIST(list->clist),
-		sel_row, -1, 0.5f, 0.0f
+		sel_item, -1, 0.5f, 0.0f
 	    ); 
 
 
@@ -1335,7 +1835,7 @@ const gchar *PUListMapQuery(
 	/* Unmap */
 	gtk_widget_hide(toplevel);
 	gtk_widget_hide(shadow);
-	GDK_PIXMAP_UNREF(list->shadow_pm)
+	GDK_PIXMAP_UNREF(list->shadow_pm);
 	list->shadow_pm = NULL;
 
 #if 0
@@ -1519,13 +2019,13 @@ void PUListDelete(pulist_struct *list)
 	}
 
 	/* Begin destroying widgets */
-	GTK_WIDGET_DESTROY(list->shadow)
-	GTK_WIDGET_DESTROY(list->clist)
-	GTK_WIDGET_DESTROY(list->scrolled_window)
-	GTK_WIDGET_DESTROY(list->main_vbox)
-	GTK_WIDGET_DESTROY(list->toplevel)
+	GTK_WIDGET_DESTROY(list->shadow);
+	GTK_WIDGET_DESTROY(list->clist);
+	GTK_WIDGET_DESTROY(list->scrolled_window);
+	GTK_WIDGET_DESTROY(list->main_vbox);
+	GTK_WIDGET_DESTROY(list->toplevel);
 
-	GDK_PIXMAP_UNREF(list->shadow_pm)
+	GDK_PIXMAP_UNREF(list->shadow_pm);
 
 	g_free(list->last_value);
 
@@ -1583,7 +2083,7 @@ GtkWidget *PUListNewMapButton(
  *      map button with an arrow.
  */
 GtkWidget *PUListNewMapButtonArrow(
-	gint arrow_type, gint shadow_type,
+	GtkArrowType arrow_type, GtkShadowType shadow_type,
 	void (*map_cb)(GtkWidget *, gpointer),
 	gpointer client_data
 )
@@ -1616,3 +2116,177 @@ GtkWidget *PUListNewMapButtonArrow(
 
 	return(button);
 }
+
+
+/*
+ *	Returns the Popup List Box's toplevel widget.
+ */
+GtkWidget *PUListBoxGetToplevel(pulistbox_struct *box)
+{
+	return((box != NULL) ? box->toplevel : NULL);
+}
+
+/*
+ *	Returns the Popup List Box's Popup List.
+ */
+pulist_struct *PUListBoxGetPUList(pulistbox_struct *box)
+{
+	return((box != NULL) ? box->pulist : NULL);
+}
+
+
+/*
+ *	Creates a new Popup List Box.
+ */
+pulistbox_struct *PUListBoxNew(
+	GtkWidget *parent,
+	gint width, gint height
+)
+{
+	GtkWidget *w;
+	pulistbox_struct *box = PULISTBOX(g_malloc0(
+	    sizeof(pulistbox_struct)
+	));
+	if(box == NULL)
+	    return(NULL);
+
+	/* Toplevel hbox */
+	box->toplevel = w = gtk_hbox_new(FALSE, 0);
+	gtk_widget_set_usize(w, width, height);
+	if(parent != NULL)
+	{
+	    if(GTK_IS_BOX(parent))
+		gtk_box_pack_start(
+		    GTK_BOX(parent), w,
+		    (width <= 0) ? TRUE : FALSE,
+		    (width <= 0) ? TRUE : FALSE,   
+		    0
+		);   
+	    else
+		gtk_container_add(
+		    GTK_CONTAINER(parent), w
+		);
+	}
+	parent = w;
+
+	/* GtkDrawingArea */
+	box->da = w = gtk_drawing_area_new();
+	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_FOCUS);
+	gtk_widget_add_events(                 
+	    w,
+	    GDK_STRUCTURE_MASK | GDK_EXPOSURE_MASK |
+	    GDK_FOCUS_CHANGE_MASK |
+	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "expose_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "focus_in_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "focus_out_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "key_press_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "key_release_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);   
+	gtk_signal_connect(                                      
+	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_release_event",             
+	    GTK_SIGNAL_FUNC(PUListBoxEventCB), box
+	);
+	if(height <= 0)
+	    gtk_widget_set_usize(w, -1, 20 + (2 * 2));
+	gtk_box_pack_start(
+	    GTK_BOX(parent), w,
+	    (width <= 0) ? TRUE : FALSE,
+	    (width <= 0) ? TRUE : FALSE, 
+	    0
+	);
+	gtk_widget_show(w);
+
+	/* Map button */
+	box->map_btn = w = PUListNewMapButtonArrow(
+	    GTK_ARROW_DOWN, GTK_SHADOW_OUT,
+	    PUListBoxMapCB, box
+	);
+	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+
+
+	/* Popup List */
+	box->pulist = PUListNew();
+
+	return(box);
+}
+
+/*
+ *	Sets the Popup List Box's changed callback.
+ */
+void PUListBoxSetChangedCB(
+	pulistbox_struct *box,
+	void (*func)(
+		pulistbox_struct *,	/* Popup List Box */
+		gint,			/* Item */         
+		gpointer		/* Data */ 
+	),   
+	gpointer data 
+)
+{
+	if(box == NULL)
+	    return;
+
+	box->changed_cb = func;
+	box->changed_data = data;
+}
+
+/*
+ *	Maps the Popup List Box.
+ */
+void PUListBoxMap(pulistbox_struct *box)
+{
+	GtkWidget *w = (box != NULL) ? box->toplevel : NULL;
+	if(w == NULL)
+	    return;
+
+	gtk_widget_show(w);
+}
+
+/*
+ *	Unmaps the Popup List Box.
+ */
+void PUListBoxUnmap(pulistbox_struct *box)
+{
+	GtkWidget *w = (box != NULL) ? box->toplevel : NULL;
+	if(w == NULL)
+	    return;
+
+	gtk_widget_hide(w);
+}
+
+/*
+ *	Deletes the Popup List Box.
+ */
+void PUListBoxDelete(pulistbox_struct *box)
+{
+	if(box == NULL)
+	    return;
+
+	PUListDelete(box->pulist);
+	GTK_WIDGET_DESTROY(box->da);
+	GTK_WIDGET_DESTROY(box->map_btn);
+	GTK_WIDGET_DESTROY(box->toplevel);
+	g_free(box);
+}
