@@ -1,6 +1,5 @@
 #include <stdlib.h>
 #include <ctype.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -13,17 +12,15 @@
 #include "fb.h"
 
 #include "editor.h"
-
 #include "viewer.h"
 #include "viewercb.h"
 #include "viewerfio.h"
-
 #include "pref.h"
 #include "prefop.h"
-
 #include "manedit.h"
 #include "config.h"
 
+
 void ViewerIndexBranchDestroyCB(gpointer data);
 
 void ViewerDestroyCB(GtkObject *object, gpointer data);
@@ -81,25 +78,31 @@ void ViewerIndexCTreeExpandCB(
 void ViewerTextChangeCB(GtkEditable *editable, gpointer data);
 
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 #define ISCR(c)         (((c) == '\n') || ((c) == '\r'))
 #define ISBLANK(c)      (((c) == ' ') || ((c) == '\t'))
 
 
-
 /*
- *	Viewer index ctree item data destroy callback.
+ *	Viewer Index Item destroy callback.
  */
 void ViewerIndexBranchDestroyCB(gpointer data)
 {
-	viewer_index_item_struct *item_ptr = VIEWER_INDEX_ITEM(data);
-	if(item_ptr == NULL)
+	viewer_index_item_struct *item = VIEWER_INDEX_ITEM(data);
+	if(item == NULL)
 	    return;
 
-	ViewerIndexItemDelete(item_ptr);
+	ViewerIndexItemDelete(item);
 }
 
 /*
@@ -679,7 +682,7 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 {
 	GtkCTree *ctree;
 	GtkCTreeNode *branch;
-	viewer_index_item_struct *item_ptr;
+	viewer_index_item_struct *item;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
@@ -699,22 +702,22 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 	if(branch == NULL)
 	    return;
 
-	item_ptr = VIEWER_INDEX_ITEM(
+	item = VIEWER_INDEX_ITEM(
 	    gtk_ctree_node_get_row_data(ctree, branch)
 	);
-	if(item_ptr == NULL)
+	if(item == NULL)
 	    return;
 
-	if(item_ptr->type == ViewerIndexItemTypeManualPage)
+	if(item->type == ViewerIndexItemTypeManualPage)
 	{
-	    if(item_ptr->file_name_full != NULL)
+	    if(item->full_path != NULL)
 	    {
 		ViewerSetBusy(v);
 		ViewerViewTextRecordScrollPositions(v);
 		ViewerTextDelete(v, 0, -1);
 		ViewerTextInsertPosition(v, 0);
 		ViewerLoadFile(
-		    v, item_ptr->file_name_full, item_ptr->file_name_full
+		    v, item->full_path, item->full_path
 		);
 		ViewerSetReady(v);
 	    }
@@ -792,10 +795,8 @@ void ViewerIndexRefreshCB(GtkWidget *widget, gpointer data)
 			))
 			    name_ptr = NULL;
 
-			path[i] = (path_ptr != NULL) ?
-			    g_strdup(path_ptr) : NULL;
-			name[i] = (name_ptr != NULL) ?
-			    g_strdup(name_ptr) : NULL;
+			path[i] = STRDUP(path_ptr);
+			name[i] = STRDUP(name_ptr);
 		    }
 		}
 	    }
@@ -1069,17 +1070,12 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 
 
 	/* Get search string and make a copy of it */
-	search_string = gtk_entry_get_text(
+	search_string = STRDUP(gtk_entry_get_text(
 	    GTK_ENTRY(combo->entry)
-	);
-	if(search_string != NULL)
-	    search_string = g_strdup(search_string);
+	));
 
 	/* Get name, which is just the search string at this point */
-	if(search_string != NULL)
-	    name = g_strdup(search_string);
-	else
-	    name = NULL;
+	name = STRDUP(search_string);
 
 	/* Check if search string is empty */
 	if((*search_string) == '\0')
@@ -1160,11 +1156,10 @@ static void ViewerDoFindCB(
 )
 {
 	gboolean got_match, search_wrapped;
-	GtkText *text; 
-	GtkEditable *editable;
 	gint start_pos;
-	gchar *s, *haystack = NULL, *needle = NULL;
-
+	gchar *haystack = NULL, *needle = NULL;
+	GtkEditable *editable;
+	GtkText *text; 
 
 	if((v == NULL) || (find_combo == NULL))
 	    return;
@@ -1173,12 +1168,13 @@ static void ViewerDoFindCB(
 	text = (GtkText *)v->view_text;
 	if(text == NULL)
 	    return;
-	else
-	    editable = GTK_EDITABLE(text);
+
+	editable = GTK_EDITABLE(text);
 
 	/* Get needle buffer (coppied) */
-	s = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
-	needle = (s != NULL) ? g_strdup(s) : NULL;
+	needle = STRDUP(gtk_entry_get_text(
+	    GTK_ENTRY(find_combo->entry)
+	));
 
 	/* Get haystack from text */
 	haystack = gtk_editable_get_chars(editable, 0, -1);
@@ -1334,7 +1330,7 @@ static void ViewerDoFindInPagesCB(
 {
 	gboolean got_match;
 	gint pass, row_num, start_row;
-	gchar *s, *needle = NULL;
+	gchar *needle = NULL;
 	GList *glist;
 	GtkCList *clist;
 	GtkCTree *ctree;
@@ -1347,12 +1343,13 @@ static void ViewerDoFindInPagesCB(
 	ctree = (GtkCTree *)v->index_ctree;
 	if(ctree == NULL)
 	    return;
-	else
-	    clist = GTK_CLIST(ctree);
+
+	clist = GTK_CLIST(ctree);
 
 	/* Get needle buffer (coppied) */
-	s = gtk_entry_get_text(GTK_ENTRY(find_combo->entry));
-	needle = (s != NULL) ? g_strdup(s) : NULL;
+	needle = STRDUP(gtk_entry_get_text(
+	    GTK_ENTRY(find_combo->entry)
+	));
 	if(needle == NULL)
 	    return;
 
@@ -1417,7 +1414,7 @@ static void ViewerDoFindInPagesCB(
 	{
 	    GtkCTreeNode *node;
 	    GtkCTreeRow *ctree_row_ptr;
-	    viewer_index_item_struct *item_ptr;
+	    viewer_index_item_struct *item;
 
 	    row_num = MAX(start_row, 0);
 
@@ -1446,19 +1443,19 @@ static void ViewerDoFindInPagesCB(
 		}
 
 		/* Get item data structure */
-		item_ptr = VIEWER_INDEX_ITEM(
+		item = VIEWER_INDEX_ITEM(
 		    gtk_ctree_node_get_row_data(ctree, node)
 		);
-		if(item_ptr == NULL)
+		if(item == NULL)
 		    continue;
 
-		ViewerSetStatusMessage(v, item_ptr->file_name_full);
+		ViewerSetStatusMessage(v, item->full_path);
 
 		/* Check if the string needle exists in the contents of
 		 * the file referenced by the item data structure
 		 */
 		got_match = ViewerFindInPagesDoGrep(
-		    item_ptr->file_name_full, needle, case_sensitive
+		    item->full_path, needle, case_sensitive
 		);
 		if(got_match)
 		{
