@@ -5,13 +5,13 @@
 #ifndef VIEWERFIO_H
 #define VIEWERFIO_H
 
-#include <sys/types.h>
 #include <gtk/gtk.h>
-
 #include "viewer.h"
 
-extern int ViewerLoadFile(
-	viewer_struct *v, const char *filename, const char *name
+
+extern gint ViewerLoadFile(
+	viewer_struct *v, const gchar *filename, const gchar *name
 );
 
+
 #endif	/* VIEWERFIO_H */
